# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetPredictorGameBanner(BaseModel):
    get_predictor_game_banner: Optional[
        "GetPredictorGameBannerGetPredictorGameBanner"
    ] = Field(alias="getPredictorGameBanner")


class GetPredictorGameBannerGetPredictorGameBanner(BaseModel):
    id: Optional[int]
    desktop_banner_id: Optional[str] = Field(alias="desktopBannerId")
    desktop_banner_edited: Optional[str] = Field(alias="desktopBannerEdited")
    mobile_banner_id: Optional[str] = Field(alias="mobileBannerId")
    mobile_banner_edited: Optional[str] = Field(alias="mobileBannerEdited")
    banner_url: Optional[str] = Field(alias="bannerUrl")
    is_live: Optional[bool] = Field(alias="isLive")


GetPredictorGameBanner.model_rebuild()
