# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSchedule(BaseModel):
    get_schedule: Optional["GetScheduleGetSchedule"] = Field(alias="getSchedule")


class GetScheduleGetSchedule(BaseModel):
    id: Optional[str]
    country_id: Optional[str] = Field(alias="countryId")
    country_name: Optional[str] = Field(alias="countryName")
    event_id: Optional[str] = Field(alias="eventId")
    event_id_wa: Optional[str] = Field(alias="eventId_WA")
    days: Optional[List[Optional["GetScheduleGetScheduleDays"]]]


class GetScheduleGetScheduleDays(BaseModel):
    day: Optional[int]
    date: Optional[Any]
    channels: Optional[List[Optional["GetScheduleGetScheduleDaysChannels"]]]


class GetScheduleGetScheduleDaysChannels(BaseModel):
    id: Optional[str] = Field(alias="_id")
    category: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_file_name: Optional[str] = Field(alias="logoFileName")
    title: Optional[str]
    time: Optional[List[Optional[str]]]


GetSchedule.model_rebuild()
GetScheduleGetSchedule.model_rebuild()
GetScheduleGetScheduleDays.model_rebuild()
