# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetTopPanel(BaseModel):
    get_top_panel: Optional[List[Optional["GetTopPanelGetTopPanel"]]] = Field(
        alias="getTopPanel"
    )


class GetTopPanelGetTopPanel(BaseModel):
    title: Optional[str]
    subtitle: Optional[str]
    description: Optional[str]
    button_label: Optional[str] = Field(alias="buttonLabel")
    button_link: Optional[str] = Field(alias="buttonLink")
    logo: Optional[str]


GetTopPanel.model_rebuild()
