# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetUserCountry(BaseModel):
    get_user_country: Optional["GetUserCountryGetUserCountry"] = Field(
        alias="getUserCountry"
    )


class GetUserCountryGetUserCountry(BaseModel):
    ip: Optional[str]
    country: Optional[str]


GetUserCountry.model_rebuild()
