# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetPredictorGameNotification(BaseModel):
    get_predictor_game_notification: Optional[
        "GetPredictorGameNotificationGetPredictorGameNotification"
    ] = Field(alias="getPredictorGameNotification")


class GetPredictorGameNotificationGetPredictorGameNotification(BaseModel):
    id: Optional[int]
    notification_text: Optional[str] = Field(alias="notificationText")
    notification_button_text: Optional[str] = Field(alias="notificationButtonText")
    notification_url: Optional[str] = Field(alias="notificationUrl")
    created_at: Optional[Any] = Field(alias="createdAt")
    published_at: Optional[Any] = Field(alias="publishedAt")


GetPredictorGameNotification.model_rebuild()
