# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetContactPreferences(BaseModel):
    get_contact_preferences: Optional[
        "GetContactPreferencesGetContactPreferences"
    ] = Field(alias="getContactPreferences")


class GetContactPreferencesGetContactPreferences(BaseModel):
    success: bool
    data: Optional["GetContactPreferencesGetContactPreferencesData"]
    error: Optional[str]


class GetContactPreferencesGetContactPreferencesData(BaseModel):
    contact_preferences: Optional[List[Optional[str]]] = Field(
        alias="contactPreferences"
    )
    consents: Optional[List[Optional[str]]]


GetContactPreferences.model_rebuild()
GetContactPreferencesGetContactPreferences.model_rebuild()
