# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SignCookies(BaseModel):
    sign_cookies: Optional["SignCookiesSignCookies"] = Field(alias="signCookies")


class SignCookiesSignCookies(BaseModel):
    signed_cookies: Optional[str] = Field(alias="signedCookies")


SignCookies.model_rebuild()
