# Generated by ariadne-codegen

from .air_quality_device_element_reads import (
    AirQualityDeviceElementReads,
    AirQualityDeviceElementReadsAirQualityDeviceElementReads,
)
from .air_quality_devices import (
    AirQualityDevices,
    AirQualityDevicesAirQualityDevices,
    AirQualityDevicesAirQualityDevicesLocation,
)
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel, Upload
from .client import WorldAthletics
from .competition_document import (
    CompetitionDocument,
    CompetitionDocumentCompetitionDocument,
)
from .competitions_by_country import (
    CompetitionsByCountry,
    CompetitionsByCountryCompetitionsByCountry,
    CompetitionsByCountryCompetitionsByCountryParameters,
    CompetitionsByCountryCompetitionsByCountryResults,
)
from .countries_by_event_id import (
    CountriesByEventId,
    CountriesByEventIdCountriesByEventId,
)
from .current_record_holder import (
    CurrentRecordHolder,
    CurrentRecordHolderCurrentRecordHolder,
    CurrentRecordHolderCurrentRecordHolderCompetitor,
)
from .disciplines_by_event_id import (
    DisciplinesByEventId,
    DisciplinesByEventIdDisciplinesByEventId,
)
from .enums import (
    AirQualityDeviceFilter,
    CarouselTypeEnum,
    GenderType,
    MetaDataTypes,
    OrderByEnum,
    OrderByLiveBlogPostEnum,
    OrderByNewArticleEnum,
    OrderDirectionEnum,
    PlacingTableOrderBy,
    RelatedCompetitionEnum,
    TeamStandingOrderBy,
    eventPhaseOrderByEnum,
    medalsOrderByEnum,
)
from .event_media import (
    EventMedia,
    EventMediaEventMedia,
    EventMediaEventMediaMedia,
    EventMediaEventMediaQuery,
)
from .get_all_competitions import (
    GetAllCompetitions,
    GetAllCompetitionsGetAllCompetitions,
    GetAllCompetitionsGetAllCompetitionsAllEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesBannersPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLocationsLocation,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEventsCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEventsPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSectionsLinks,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesVideosThumbnailImage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisite,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsorsLightBgLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsorsDarkBgLogo,
    GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsorsLightBgLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesBanners,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesBannersPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesFeatureLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLifestyleLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLocations,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLocationsLocation,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedArticles,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedCompetitors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedDiscipline,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEvents,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEventsCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEventsPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedMedia,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedVideo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSections,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSectionsLinks,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSlides,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesVideos,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesVideosThumbnailImage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventCircuits,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageCampaign,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageContentModules,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageEvent,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisite,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteFeatureImage,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsors,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsorsDarkBgLogo,
    GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsorsLightBgLogo,
)
from .get_all_event_phases_by_discipline import (
    GetAllEventPhasesByDiscipline,
    GetAllEventPhasesByDisciplineGetAllEventPhasesByDiscipline,
    GetAllEventPhasesByDisciplineGetAllEventPhasesByDisciplineDiscipline,
)
from .get_all_gold_tour_events import (
    GetAllGoldTourEvents,
    GetAllGoldTourEventsGetAllGoldTourEvents,
    GetAllGoldTourEventsGetAllGoldTourEventsEvents,
)
from .get_all_schedules import (
    GetAllSchedules,
    GetAllSchedulesGetAllSchedules,
    GetAllSchedulesGetAllSchedulesDays,
    GetAllSchedulesGetAllSchedulesDaysChannels,
)
from .get_all_time_list import (
    GetAllTimeList,
    GetAllTimeListGetAllTimeList,
    GetAllTimeListGetAllTimeListPayload,
)
from .get_appearance import (
    GetAppearance,
    GetAppearanceGetAppearance,
    GetAppearanceGetAppearanceDefaultSponsors,
    GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo,
    GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo,
    GetAppearanceGetAppearanceFeatureImage,
    GetAppearanceGetAppearanceLogo,
    GetAppearanceGetAppearanceSponsors,
    GetAppearanceGetAppearanceSponsorsDarkBgLogo,
    GetAppearanceGetAppearanceSponsorsLightBgLogo,
)
from .get_article import (
    GetArticle,
    GetArticleGetArticle,
    GetArticleGetArticleLocation,
    GetArticleGetArticleRelatedArticles,
    GetArticleGetArticleRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageCampaign,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModules,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEvent,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEventCircuits,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEventPage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisite,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo,
    GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetArticleGetArticleRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedCompetitions,
    GetArticleGetArticleRelatedCompetitionsLastEvent,
    GetArticleGetArticleRelatedCompetitionsLastEventCircuits,
    GetArticleGetArticleRelatedCompetitionsLastEventPage,
    GetArticleGetArticleRelatedCompetitionsLastEventPageCampaign,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModules,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesBanners,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesLocations,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesMinisite,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesSections,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesSlides,
    GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesVideos,
    GetArticleGetArticleRelatedCompetitionsLastEventPageEvent,
    GetArticleGetArticleRelatedCompetitionsLastEventPageEventCircuits,
    GetArticleGetArticleRelatedCompetitionsLastEventPageEventPage,
    GetArticleGetArticleRelatedCompetitionsLastEventPageMinisite,
    GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors,
    GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage,
    GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteLogo,
    GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteSponsors,
    GetArticleGetArticleRelatedCompetitionsNextEvent,
    GetArticleGetArticleRelatedCompetitionsNextEventCircuits,
    GetArticleGetArticleRelatedCompetitionsNextEventPage,
    GetArticleGetArticleRelatedCompetitionsNextEventPageCampaign,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModules,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesBanners,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesLocations,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesMinisite,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesSections,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesSlides,
    GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesVideos,
    GetArticleGetArticleRelatedCompetitionsNextEventPageEvent,
    GetArticleGetArticleRelatedCompetitionsNextEventPageEventCircuits,
    GetArticleGetArticleRelatedCompetitionsNextEventPageEventPage,
    GetArticleGetArticleRelatedCompetitionsNextEventPageMinisite,
    GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors,
    GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage,
    GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteLogo,
    GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteSponsors,
    GetArticleGetArticleRelatedCompetitionsPage,
    GetArticleGetArticleRelatedCompetitionsPageCampaign,
    GetArticleGetArticleRelatedCompetitionsPageContentModules,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesBanners,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesBannersPage,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesFeatureLinks,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesLocations,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesLocationsLocation,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisite,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteLogo,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePage,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageEvent,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteSponsors,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticles,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEvents,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEventsPage,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedMedia,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedVideo,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedVideos,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesSections,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesSectionsLinks,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesSlides,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesVideos,
    GetArticleGetArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage,
    GetArticleGetArticleRelatedCompetitionsPageEvent,
    GetArticleGetArticleRelatedCompetitionsPageEventCircuits,
    GetArticleGetArticleRelatedCompetitionsPageEventPage,
    GetArticleGetArticleRelatedCompetitionsPageEventPageCampaign,
    GetArticleGetArticleRelatedCompetitionsPageEventPageContentModules,
    GetArticleGetArticleRelatedCompetitionsPageEventPageEvent,
    GetArticleGetArticleRelatedCompetitionsPageEventPageMinisite,
    GetArticleGetArticleRelatedCompetitionsPageMinisite,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteFeatureImage,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteLogo,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsors,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo,
    GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo,
    GetArticleGetArticleRelatedCompetitors,
    GetArticleGetArticleRelatedCompetitorsRelatedMedia,
    GetArticleGetArticleRelatedDiscipline,
    GetArticleGetArticleRelatedMedia,
)
from .get_article_locations import (
    GetArticleLocations,
    GetArticleLocationsGetArticleLocations,
)
from .get_articles import (
    GetArticles,
    GetArticlesGetArticles,
    GetArticlesGetArticlesLocation,
    GetArticlesGetArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageCampaign,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageContentModules,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageMinisite,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageCampaign,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageContentModules,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageMinisite,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesBanners,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLocations,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSections,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSlides,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesVideos,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEventCircuits,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEventPage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteLogo,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedCompetitionsLastEvent,
    GetArticlesGetArticlesRelatedCompetitionsLastEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPage,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesBanners,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesFeatureLinks,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesLifestyleLinks,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesLocations,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesMinisite,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesMinisitePage,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedArticles,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedEvents,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideo,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideos,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesSections,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesSlides,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesVideos,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageEvent,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageEventPage,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisite,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteDefaultSponsors,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteFeatureImage,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteLogo,
    GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteSponsors,
    GetArticlesGetArticlesRelatedCompetitionsNextEvent,
    GetArticlesGetArticlesRelatedCompetitionsNextEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPage,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesBanners,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesFeatureLinks,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesLifestyleLinks,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesLocations,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesMinisite,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesMinisitePage,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedArticles,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedEvents,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideo,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideos,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesSections,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesSlides,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesVideos,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageEvent,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageEventPage,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisite,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteDefaultSponsors,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteFeatureImage,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteLogo,
    GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteSponsors,
    GetArticlesGetArticlesRelatedCompetitionsPage,
    GetArticlesGetArticlesRelatedCompetitionsPageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesBanners,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesBannersPage,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLocations,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLocationsLocation,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteFeatureImage,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteLogo,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageEvent,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageMinisite,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteSponsors,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesContentModules,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesEvent,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEventsCircuits,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEventsPage,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSections,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSectionsLinks,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSlides,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesVideos,
    GetArticlesGetArticlesRelatedCompetitionsPageContentModulesVideosThumbnailImage,
    GetArticlesGetArticlesRelatedCompetitionsPageEvent,
    GetArticlesGetArticlesRelatedCompetitionsPageEventCircuits,
    GetArticlesGetArticlesRelatedCompetitionsPageEventPage,
    GetArticlesGetArticlesRelatedCompetitionsPageEventPageCampaign,
    GetArticlesGetArticlesRelatedCompetitionsPageEventPageContentModules,
    GetArticlesGetArticlesRelatedCompetitionsPageEventPageEvent,
    GetArticlesGetArticlesRelatedCompetitionsPageEventPageMinisite,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisite,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteLogo,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo,
    GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsorsLightBgLogo,
    GetArticlesGetArticlesRelatedCompetitors,
    GetArticlesGetArticlesRelatedCompetitorsRelatedMedia,
    GetArticlesGetArticlesRelatedDiscipline,
    GetArticlesGetArticlesRelatedMedia,
)
from .get_asset import (
    GetAsset,
    GetAssetGetAsset,
    GetAssetGetAssetCampaign,
    GetAssetGetAssetDocument,
    GetAssetGetAssetFilters,
    GetAssetGetAssetFiltersType,
    GetAssetGetAssetFiltersTypeFilters,
    GetAssetGetAssetFiltersTypeFiltersType,
    GetAssetGetAssetFiltersTypeFiltersTypeFilters,
    GetAssetGetAssetThumbnailFeatureImage,
)
from .get_assets import (
    GetAssets,
    GetAssetsGetAssets,
    GetAssetsGetAssetsCampaign,
    GetAssetsGetAssetsDocument,
    GetAssetsGetAssetsFilters,
    GetAssetsGetAssetsFiltersType,
    GetAssetsGetAssetsFiltersTypeFilters,
    GetAssetsGetAssetsFiltersTypeFiltersType,
    GetAssetsGetAssetsFiltersTypeFiltersTypeFilters,
    GetAssetsGetAssetsThumbnailFeatureImage,
)
from .get_assets_dates import GetAssetsDates, GetAssetsDatesGetAssetsDates
from .get_assets_total import GetAssetsTotal, GetAssetsTotalGetAssetsTotal
from .get_athlete import (
    GetAthlete,
    GetAthleteGetAthlete,
    GetAthleteGetAthletePrimaryMedia,
)
from .get_athlete_profile_athlete_representative import (
    GetAthleteProfileAthleteRepresentative,
    GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative,
)
from .get_athlete_representative_athlete_search import (
    GetAthleteRepresentativeAthleteSearch,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren,
    GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries,
)
from .get_athlete_representative_directory import (
    GetAthleteRepresentativeDirectory,
    GetAthleteRepresentativeDirectoryGetAthleteRepresentativeDirectory,
)
from .get_athlete_representative_profile import (
    GetAthleteRepresentativeProfile,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist,
    GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes,
)
from .get_athlete_representative_top_list import (
    GetAthleteRepresentativeTopList,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist,
    GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes,
)
from .get_athlete_results import (
    GetAthleteResults,
    GetAthleteResultsGetAthleteResults,
    GetAthleteResultsGetAthleteResultsTeamMembers,
)
from .get_banners import (
    GetBanners,
    GetBannersGetBanners,
    GetBannersGetBannersBannerItems,
    GetBannersGetBannersBannerItemsPrimaryMedia,
)
from .get_calendar_competition_results import (
    GetCalendarCompetitionResults,
    GetCalendarCompetitionResultsGetCalendarCompetitionResults,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResults,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsCompetitor,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsDetails,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartList,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartListCompetitor,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitor,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitorTeamMembers,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents,
    GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters,
)
from .get_calendar_events import (
    GetCalendarEvents,
    GetCalendarEventsGetCalendarEvents,
    GetCalendarEventsGetCalendarEventsOptions,
    GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups,
    GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups,
    GetCalendarEventsGetCalendarEventsOptionsDisciplines,
    GetCalendarEventsGetCalendarEventsOptionsPermitLevels,
    GetCalendarEventsGetCalendarEventsOptionsRankingCategories,
    GetCalendarEventsGetCalendarEventsOptionsRegions,
    GetCalendarEventsGetCalendarEventsOptionsRegionsArea,
    GetCalendarEventsGetCalendarEventsOptionsRegionsCountry,
    GetCalendarEventsGetCalendarEventsOptionsRegionsWorld,
    GetCalendarEventsGetCalendarEventsOptionsSeasons,
    GetCalendarEventsGetCalendarEventsParameters,
    GetCalendarEventsGetCalendarEventsResults,
    GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod,
)
from .get_campaign import GetCampaign, GetCampaignGetCampaign
from .get_campaigns import GetCampaigns, GetCampaignsGetCampaigns
from .get_carousel import (
    GetCarousel,
    GetCarouselGetCarousel,
    GetCarouselGetCarouselCarouselItems,
    GetCarouselGetCarouselCarouselItemsPrimaryMedia,
    GetCarouselGetCarouselMedia,
)
from .get_championship_highlights import (
    GetChampionshipHighlights,
    GetChampionshipHighlightsGetChampionshipHighlights,
    GetChampionshipHighlightsGetChampionshipHighlightsDays,
    GetChampionshipHighlightsGetChampionshipHighlightsRounds,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecords,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitorTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitorTeamMembersTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHead,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitorPrimaryMedia,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponents,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsOpponent,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsOpponentPrimaryMedia,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsResults,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlights,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitors,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitorsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitorsCompetitorTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalists,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitorTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitorTeamMembersTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecords,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitor,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitorTeamMembers,
    GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitorTeamMembersTeamMembers,
)
from .get_championship_qualifications import (
    GetChampionshipQualifications,
    GetChampionshipQualificationsGetChampionshipQualifications,
    GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards,
    GetChampionshipQualificationsGetChampionshipQualificationsCountries,
    GetChampionshipQualificationsGetChampionshipQualificationsEvents,
    GetChampionshipQualificationsGetChampionshipQualificationsQualifications,
    GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes,
)
from .get_cis_competitor_res_date import (
    GetCISCompetitorResDate,
    GetCISCompetitorResDateGetCisCompetitorResDate,
    GetCISCompetitorResDateGetCisCompetitorResDateParameters,
    GetCISCompetitorResDateGetCisCompetitorResDateResultsByDate,
)
from .get_cis_competitor_res_disp import (
    GetCISCompetitorResDisp,
    GetCISCompetitorResDispGetCisCompetitorResDisp,
    GetCISCompetitorResDispGetCisCompetitorResDispParameters,
    GetCISCompetitorResDispGetCisCompetitorResDispResultsByDate,
    GetCISCompetitorResDispGetCisCompetitorResDispResultsByEvent,
    GetCISCompetitorResDispGetCisCompetitorResDispResultsByEventResults,
)
from .get_cis_single_competitor import (
    GetCISSingleCompetitor,
    GetCISSingleCompetitorGetCisSingleCompetitor,
    GetCISSingleCompetitorGetCisSingleCompetitorAthleteRepresentative,
    GetCISSingleCompetitorGetCisSingleCompetitorBasicData,
    GetCISSingleCompetitorGetCisSingleCompetitorHonours,
    GetCISSingleCompetitorGetCisSingleCompetitorHonoursResults,
    GetCISSingleCompetitorGetCisSingleCompetitorPersonalBests,
    GetCISSingleCompetitorGetCisSingleCompetitorPersonalBestsResults,
    GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBests,
    GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBestsResults,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByDate,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateParameters,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateResultsByDate,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByYear,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearParameters,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEvent,
    GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEventResults,
    GetCISSingleCompetitorGetCisSingleCompetitorRoadRaceLabelStatus,
    GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBests,
    GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsParameters,
    GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsResults,
    GetCISSingleCompetitorGetCisSingleCompetitorWorldRankings,
    GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsBest,
    GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsCurrent,
    GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsParameters,
)
from .get_combined_points import (
    GetCombinedPoints,
    GetCombinedPointsGetCombinedPoints,
    GetCombinedPointsGetCombinedPointsAllDisciplines,
    GetCombinedPointsGetCombinedPointsCompetitors,
    GetCombinedPointsGetCombinedPointsCompetitorsDisciplines,
)
from .get_competition_organiser_info import (
    GetCompetitionOrganiserInfo,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersons,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoPrizeMoney,
    GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits,
)
from .get_competitor import GetCompetitor, GetCompetitorGetCompetitor
from .get_competitor_aa_id import GetCompetitorAAId
from .get_competitors_legacy_primary_media import (
    GetCompetitorsLegacyPrimaryMedia,
    GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia,
)
from .get_contact_preferences import (
    GetContactPreferences,
    GetContactPreferencesGetContactPreferences,
    GetContactPreferencesGetContactPreferencesData,
)
from .get_countries import GetCountries, GetCountriesGetCountries
from .get_discipline import GetDiscipline, GetDisciplineGetDiscipline
from .get_drafted_article import (
    GetDraftedArticle,
    GetDraftedArticleGetDraftedArticle,
    GetDraftedArticleGetDraftedArticleContentModules,
    GetDraftedArticleGetDraftedArticleContentModulesLocations,
    GetDraftedArticleGetDraftedArticleContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleEvent,
    GetDraftedArticleGetDraftedArticleEventCircuits,
    GetDraftedArticleGetDraftedArticleEventPage,
    GetDraftedArticleGetDraftedArticleEventPageCampaign,
    GetDraftedArticleGetDraftedArticleEventPageContentModules,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesBannersPage,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageCampaign,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageContentModules,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageEvent,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageMinisite,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesSectionsLinks,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleEventPageContentModulesVideosThumbnailImage,
    GetDraftedArticleGetDraftedArticleEventPageEvent,
    GetDraftedArticleGetDraftedArticleEventPageEventCircuits,
    GetDraftedArticleGetDraftedArticleEventPageEventPage,
    GetDraftedArticleGetDraftedArticleEventPageEventPageCampaign,
    GetDraftedArticleGetDraftedArticleEventPageEventPageContentModules,
    GetDraftedArticleGetDraftedArticleEventPageEventPageEvent,
    GetDraftedArticleGetDraftedArticleEventPageEventPageMinisite,
    GetDraftedArticleGetDraftedArticleEventPageMinisite,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStats,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsRecords,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResults,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResultsDetails,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsTimetable,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesBannersPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesBannersPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSectionsLinks,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStats,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsPreviousMedalists,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsRecords,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResults,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResults,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsCompetitor,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsCompetitorTeamMembers,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsDetails,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsStartList,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsStartListCompetitor,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsSeasonBest,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsTimetable,
    GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsTimetableDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesBannersPage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageEvent,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSectionsLinks,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesVideosThumbnailImage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocationsLocation,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinksFile,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinksPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageCampaign,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModules,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesBanners,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesFeatureLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesLifestyleLinks,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesLocations,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesMinisitePage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedArticles,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedCompetitors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedDiscipline,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedEvents,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedMedia,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedVideo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesSections,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesSlides,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesVideos,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEvent,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEventCircuits,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEventPage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisite,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteFeatureImage,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsors,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
)
from .get_event import (
    GetEvent,
    GetEventGetEvent,
    GetEventGetEventCircuits,
    GetEventGetEventRelatedMedia,
)
from .get_event_broken_records import (
    GetEventBrokenRecords,
    GetEventBrokenRecordsGetEventBrokenRecords,
    GetEventBrokenRecordsGetEventBrokenRecordsDiscipline,
)
from .get_event_circuit_standings import (
    GetEventCircuitStandings,
    GetEventCircuitStandingsGetEventCircuitStandings,
    GetEventCircuitStandingsGetEventCircuitStandingsParameters,
    GetEventCircuitStandingsGetEventCircuitStandingsStandings,
    GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries,
    GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults,
)
from .get_event_leading_standings import (
    GetEventLeadingStandings,
    GetEventLeadingStandingsGetEventLeadingStandings,
    GetEventLeadingStandingsGetEventLeadingStandingsDiscipline,
)
from .get_event_phase_by_discipline import (
    GetEventPhaseByDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings,
    GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers,
)
from .get_event_phase_result_detail import (
    GetEventPhaseResultDetail,
    GetEventPhaseResultDetailGetEventPhaseResultDetail,
    GetEventPhaseResultDetailGetEventPhaseResultDetailDiscipline,
    GetEventPhaseResultDetailGetEventPhaseResultDetailResult,
    GetEventPhaseResultDetailGetEventPhaseResultDetailResultDiscipline,
)
from .get_event_phase_results import (
    GetEventPhaseResults,
    GetEventPhaseResultsGetEventPhaseResults,
    GetEventPhaseResultsGetEventPhaseResultsDiscipline,
    GetEventPhaseResultsGetEventPhaseResultsResult,
    GetEventPhaseResultsGetEventPhaseResultsResultDiscipline,
)
from .get_event_phases import (
    GetEventPhases,
    GetEventPhasesGetEventPhases,
    GetEventPhasesGetEventPhasesDiscipline,
)
from .get_event_team_standing_details import (
    GetEventTeamStandingDetails,
    GetEventTeamStandingDetailsGetEventTeamStandingDetails,
    GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor,
    GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline,
)
from .get_event_team_standings import (
    GetEventTeamStandings,
    GetEventTeamStandingsGetEventTeamStandings,
)
from .get_event_timetable import (
    GetEventTimetable,
    GetEventTimetableGetEventTimetable,
    GetEventTimetableGetEventTimetableDiscipline,
)
from .get_event_timetable_with_content import (
    GetEventTimetableWithContent,
    GetEventTimetableWithContentGetEventTimetableWithContent,
    GetEventTimetableWithContentGetEventTimetableWithContentDiscipline,
    GetEventTimetableWithContentGetEventTimetableWithContentDocuments,
    GetEventTimetableWithContentGetEventTimetableWithContentSummary,
    GetEventTimetableWithContentGetEventTimetableWithContentSummaryTeamMembers,
    GetEventTimetableWithContentGetEventTimetableWithContentUnits,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsResults,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsResultsTeamMembers,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsSeries,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsSeriesAttempts,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsSplits,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsStartlist,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsStartlistTeamMembers,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsTeamStandings,
    GetEventTimetableWithContentGetEventTimetableWithContentUnitsTeamStandingsTeamMembers,
)
from .get_events import (
    GetEvents,
    GetEventsGetEvents,
    GetEventsGetEventsCircuits,
    GetEventsGetEventsPage,
    GetEventsGetEventsPageCampaign,
    GetEventsGetEventsPageContentModules,
    GetEventsGetEventsPageContentModulesBanners,
    GetEventsGetEventsPageContentModulesBannersPage,
    GetEventsGetEventsPageContentModulesBannersPageCampaign,
    GetEventsGetEventsPageContentModulesBannersPageContentModules,
    GetEventsGetEventsPageContentModulesBannersPageEvent,
    GetEventsGetEventsPageContentModulesBannersPageMinisite,
    GetEventsGetEventsPageContentModulesFeatureLinks,
    GetEventsGetEventsPageContentModulesLifestyleLinks,
    GetEventsGetEventsPageContentModulesLocations,
    GetEventsGetEventsPageContentModulesLocationsLocation,
    GetEventsGetEventsPageContentModulesMinisite,
    GetEventsGetEventsPageContentModulesMinisiteDefaultSponsors,
    GetEventsGetEventsPageContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetEventsGetEventsPageContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetEventsGetEventsPageContentModulesMinisiteFeatureImage,
    GetEventsGetEventsPageContentModulesMinisiteLogo,
    GetEventsGetEventsPageContentModulesMinisitePage,
    GetEventsGetEventsPageContentModulesMinisitePageCampaign,
    GetEventsGetEventsPageContentModulesMinisitePageContentModules,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesBanners,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesFeatureLinks,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesLifestyleLinks,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesLocations,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesMinisite,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesMinisitePage,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedArticles,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedEvents,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedMedia,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedVideo,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedVideos,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesSections,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesSlides,
    GetEventsGetEventsPageContentModulesMinisitePageContentModulesVideos,
    GetEventsGetEventsPageContentModulesMinisitePageEvent,
    GetEventsGetEventsPageContentModulesMinisitePageEventCircuits,
    GetEventsGetEventsPageContentModulesMinisitePageEventPage,
    GetEventsGetEventsPageContentModulesMinisitePageMinisite,
    GetEventsGetEventsPageContentModulesMinisitePageMinisiteDefaultSponsors,
    GetEventsGetEventsPageContentModulesMinisitePageMinisiteFeatureImage,
    GetEventsGetEventsPageContentModulesMinisitePageMinisiteLogo,
    GetEventsGetEventsPageContentModulesMinisitePageMinisiteSponsors,
    GetEventsGetEventsPageContentModulesMinisiteSponsors,
    GetEventsGetEventsPageContentModulesMinisiteSponsorsDarkBgLogo,
    GetEventsGetEventsPageContentModulesMinisiteSponsorsLightBgLogo,
    GetEventsGetEventsPageContentModulesRelatedArticles,
    GetEventsGetEventsPageContentModulesRelatedArticlesContentModules,
    GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesLocations,
    GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetEventsGetEventsPageContentModulesRelatedArticlesEvent,
    GetEventsGetEventsPageContentModulesRelatedArticlesEventCircuits,
    GetEventsGetEventsPageContentModulesRelatedArticlesEventPage,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticles,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesEvent,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStats,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEvents,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEventsCircuits,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEventsPage,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedLinks,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMedia,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetEventsGetEventsPageContentModulesRelatedCompetitors,
    GetEventsGetEventsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetEventsGetEventsPageContentModulesRelatedDiscipline,
    GetEventsGetEventsPageContentModulesRelatedEvents,
    GetEventsGetEventsPageContentModulesRelatedEventsCircuits,
    GetEventsGetEventsPageContentModulesRelatedEventsPage,
    GetEventsGetEventsPageContentModulesRelatedEventsPageCampaign,
    GetEventsGetEventsPageContentModulesRelatedEventsPageContentModules,
    GetEventsGetEventsPageContentModulesRelatedEventsPageEvent,
    GetEventsGetEventsPageContentModulesRelatedEventsPageMinisite,
    GetEventsGetEventsPageContentModulesRelatedMedia,
    GetEventsGetEventsPageContentModulesRelatedVideo,
    GetEventsGetEventsPageContentModulesRelatedVideos,
    GetEventsGetEventsPageContentModulesSections,
    GetEventsGetEventsPageContentModulesSectionsLinks,
    GetEventsGetEventsPageContentModulesSectionsLinksFile,
    GetEventsGetEventsPageContentModulesSectionsLinksPage,
    GetEventsGetEventsPageContentModulesSlides,
    GetEventsGetEventsPageContentModulesVideos,
    GetEventsGetEventsPageContentModulesVideosThumbnailImage,
    GetEventsGetEventsPageEvent,
    GetEventsGetEventsPageEventCircuits,
    GetEventsGetEventsPageEventPage,
    GetEventsGetEventsPageEventPageCampaign,
    GetEventsGetEventsPageEventPageContentModules,
    GetEventsGetEventsPageEventPageContentModulesBanners,
    GetEventsGetEventsPageEventPageContentModulesFeatureLinks,
    GetEventsGetEventsPageEventPageContentModulesLifestyleLinks,
    GetEventsGetEventsPageEventPageContentModulesLocations,
    GetEventsGetEventsPageEventPageContentModulesMinisite,
    GetEventsGetEventsPageEventPageContentModulesMinisitePage,
    GetEventsGetEventsPageEventPageContentModulesRelatedArticles,
    GetEventsGetEventsPageEventPageContentModulesRelatedCompetitors,
    GetEventsGetEventsPageEventPageContentModulesRelatedDiscipline,
    GetEventsGetEventsPageEventPageContentModulesRelatedEvents,
    GetEventsGetEventsPageEventPageContentModulesRelatedMedia,
    GetEventsGetEventsPageEventPageContentModulesRelatedVideo,
    GetEventsGetEventsPageEventPageContentModulesRelatedVideos,
    GetEventsGetEventsPageEventPageContentModulesSections,
    GetEventsGetEventsPageEventPageContentModulesSlides,
    GetEventsGetEventsPageEventPageContentModulesVideos,
    GetEventsGetEventsPageEventPageEvent,
    GetEventsGetEventsPageEventPageEventCircuits,
    GetEventsGetEventsPageEventPageEventPage,
    GetEventsGetEventsPageEventPageMinisite,
    GetEventsGetEventsPageEventPageMinisiteDefaultSponsors,
    GetEventsGetEventsPageEventPageMinisiteFeatureImage,
    GetEventsGetEventsPageEventPageMinisiteLogo,
    GetEventsGetEventsPageEventPageMinisiteSponsors,
    GetEventsGetEventsPageMinisite,
    GetEventsGetEventsPageMinisiteDefaultSponsors,
    GetEventsGetEventsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetEventsGetEventsPageMinisiteDefaultSponsorsLightBgLogo,
    GetEventsGetEventsPageMinisiteFeatureImage,
    GetEventsGetEventsPageMinisiteLogo,
    GetEventsGetEventsPageMinisiteSponsors,
    GetEventsGetEventsPageMinisiteSponsorsDarkBgLogo,
    GetEventsGetEventsPageMinisiteSponsorsLightBgLogo,
)
from .get_filter_types import (
    GetFilterTypes,
    GetFilterTypesGetFilterTypes,
    GetFilterTypesGetFilterTypesFilters,
    GetFilterTypesGetFilterTypesFiltersType,
    GetFilterTypesGetFilterTypesFiltersTypeFilters,
    GetFilterTypesGetFilterTypesFiltersTypeFiltersType,
    GetFilterTypesGetFilterTypesFiltersTypeFiltersTypeFilters,
)
from .get_flash_interviews import (
    GetFlashInterviews,
    GetFlashInterviewsGetFlashInterviews,
    GetFlashInterviewsGetFlashInterviewsInterviews,
)
from .get_hero_athletes_carousel import (
    GetHeroAthletesCarousel,
    GetHeroAthletesCarouselGetHeroAthletesCarousel,
    GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia,
)
from .get_latest_qualified_competitors import (
    GetLatestQualifiedCompetitors,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor,
    GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers,
)
from .get_latest_records import (
    GetLatestRecords,
    GetLatestRecordsGetLatestRecords,
    GetLatestRecordsGetLatestRecordsRecords,
    GetLatestRecordsGetLatestRecordsRecordsCompetitor,
    GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers,
)
from .get_leading_athletes import (
    GetLeadingAthletes,
    GetLeadingAthletesGetLeadingAthletes,
    GetLeadingAthletesGetLeadingAthletesEventResults,
    GetLeadingAthletesGetLeadingAthletesEventResultsResults,
    GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitor,
    GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitorTeamMembers,
    GetLeadingAthletesGetLeadingAthletesEventResultsResultsPrimaryMedia,
)
from .get_legacy_page import (
    GetLegacyPage,
    GetLegacyPageGetLegacyPage,
    GetLegacyPageGetLegacyPageContent,
    GetLegacyPageGetLegacyPageContentLegacyDocument,
    GetLegacyPageGetLegacyPageContentLegacyDocumentFiles,
    GetLegacyPageGetLegacyPageContentRelatedMedia,
    GetLegacyPageGetLegacyPageTemplate,
)
from .get_live_blog_posts import GetLiveBlogPosts, GetLiveBlogPostsGetLiveBlogPosts
from .get_live_combined_summary_details import (
    GetLiveCombinedSummaryDetails,
    GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails,
)
from .get_live_phase_summary import (
    GetLivePhaseSummary,
    GetLivePhaseSummaryGetLivePhaseSummary,
)
from .get_live_result import (
    GetLiveResult,
    GetLiveResultGetLiveResult,
    GetLiveResultGetLiveResultTeamMembers,
)
from .get_medal import GetMedal, GetMedalGetMedal
from .get_medal_details import GetMedalDetails, GetMedalDetailsGetMedalDetails
from .get_medals import GetMedals, GetMedalsGetMedals, GetMedalsGetMedalsCountry
from .get_media import GetMedia, GetMediaGetMedia
from .get_medias import GetMedias, GetMediasGetMedias
from .get_meta_data import (
    GetMetaData,
    GetMetaDataGetMetaData,
    GetMetaDataGetMetaDataCountryCodes,
    GetMetaDataGetMetaDataDisciplineCodes,
)
from .get_minisite_calendar_events import (
    GetMinisiteCalendarEvents,
    GetMinisiteCalendarEventsGetMinisiteCalendarEvents,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults,
    GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod,
)
from .get_new_article import (
    GetNewArticle,
    GetNewArticleGetNewArticle,
    GetNewArticleGetNewArticleContentModules,
    GetNewArticleGetNewArticleContentModulesLocations,
    GetNewArticleGetNewArticleContentModulesLocationsLocation,
    GetNewArticleGetNewArticleContentModulesRelatedVideo,
    GetNewArticleGetNewArticleContentModulesRelatedVideos,
    GetNewArticleGetNewArticleEvent,
    GetNewArticleGetNewArticleEventCircuits,
    GetNewArticleGetNewArticleEventPage,
    GetNewArticleGetNewArticleEventPageCampaign,
    GetNewArticleGetNewArticleEventPageContentModules,
    GetNewArticleGetNewArticleEventPageContentModulesBanners,
    GetNewArticleGetNewArticleEventPageContentModulesBannersPage,
    GetNewArticleGetNewArticleEventPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleEventPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleEventPageContentModulesLocations,
    GetNewArticleGetNewArticleEventPageContentModulesLocationsLocation,
    GetNewArticleGetNewArticleEventPageContentModulesMinisite,
    GetNewArticleGetNewArticleEventPageContentModulesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleEventPageContentModulesMinisiteFeatureImage,
    GetNewArticleGetNewArticleEventPageContentModulesMinisiteLogo,
    GetNewArticleGetNewArticleEventPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleEventPageContentModulesMinisitePageCampaign,
    GetNewArticleGetNewArticleEventPageContentModulesMinisitePageContentModules,
    GetNewArticleGetNewArticleEventPageContentModulesMinisitePageEvent,
    GetNewArticleGetNewArticleEventPageContentModulesMinisitePageMinisite,
    GetNewArticleGetNewArticleEventPageContentModulesMinisiteSponsors,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesEvent,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedEventsCircuits,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedEventsPage,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleEventPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleEventPageContentModulesSections,
    GetNewArticleGetNewArticleEventPageContentModulesSectionsLinks,
    GetNewArticleGetNewArticleEventPageContentModulesSlides,
    GetNewArticleGetNewArticleEventPageContentModulesVideos,
    GetNewArticleGetNewArticleEventPageContentModulesVideosThumbnailImage,
    GetNewArticleGetNewArticleEventPageEvent,
    GetNewArticleGetNewArticleEventPageEventCircuits,
    GetNewArticleGetNewArticleEventPageEventPage,
    GetNewArticleGetNewArticleEventPageEventPageCampaign,
    GetNewArticleGetNewArticleEventPageEventPageContentModules,
    GetNewArticleGetNewArticleEventPageEventPageEvent,
    GetNewArticleGetNewArticleEventPageEventPageMinisite,
    GetNewArticleGetNewArticleEventPageMinisite,
    GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleEventPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleEventPageMinisiteLogo,
    GetNewArticleGetNewArticleEventPageMinisiteSponsors,
    GetNewArticleGetNewArticleEventPageMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleEventPageMinisiteSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesEventPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedArticlesEventPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesEventPageEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesEventPageEventPage,
    GetNewArticleGetNewArticleRelatedArticlesEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStats,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResultsDetails,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesBannersPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageCampaign,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageContentModules,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageEvent,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesBannersPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSectionsLinks,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventCircuits,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventPage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageCampaign,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageContentModules,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageEvent,
    GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisite,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedDisciplineStats,
    GetNewArticleGetNewArticleRelatedDisciplineStatsDiscipline,
    GetNewArticleGetNewArticleRelatedDisciplineStatsPreviousMedalists,
    GetNewArticleGetNewArticleRelatedDisciplineStatsRecords,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResults,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResults,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsCompetitor,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsCompetitorTeamMembers,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsDetails,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsStartList,
    GetNewArticleGetNewArticleRelatedDisciplineStatsResultsStartListCompetitor,
    GetNewArticleGetNewArticleRelatedDisciplineStatsSeasonBest,
    GetNewArticleGetNewArticleRelatedDisciplineStatsTimetable,
    GetNewArticleGetNewArticleRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticleGetNewArticleRelatedEvents,
    GetNewArticleGetNewArticleRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedEventsPageCampaign,
    GetNewArticleGetNewArticleRelatedEventsPageContentModules,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesBannersPage,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageCampaign,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageContentModules,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageEvent,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageMinisite,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesSectionsLinks,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedEventsPageContentModulesVideosThumbnailImage,
    GetNewArticleGetNewArticleRelatedEventsPageEvent,
    GetNewArticleGetNewArticleRelatedEventsPageEventCircuits,
    GetNewArticleGetNewArticleRelatedEventsPageEventPage,
    GetNewArticleGetNewArticleRelatedEventsPageEventPageCampaign,
    GetNewArticleGetNewArticleRelatedEventsPageEventPageContentModules,
    GetNewArticleGetNewArticleRelatedEventsPageEventPageEvent,
    GetNewArticleGetNewArticleRelatedEventsPageEventPageMinisite,
    GetNewArticleGetNewArticleRelatedEventsPageMinisite,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedLinks,
    GetNewArticleGetNewArticleRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBanners,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocationsLocation,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSections,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEventCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEventPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEventPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSections,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinksFile,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinksPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSlides,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageCampaign,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModules,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesBanners,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesFeatureLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesLifestyleLinks,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesLocations,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesMinisitePage,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedArticles,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedCompetitors,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedDiscipline,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedEvents,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedMedia,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedVideo,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesSections,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesSlides,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesVideos,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEvent,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEventCircuits,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEventPage,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisite,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsors,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
)
from .get_new_articles import (
    GetNewArticles,
    GetNewArticlesGetNewArticles,
    GetNewArticlesGetNewArticlesContentModules,
    GetNewArticlesGetNewArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesEvent,
    GetNewArticlesGetNewArticlesEventCircuits,
    GetNewArticlesGetNewArticlesEventPage,
    GetNewArticlesGetNewArticlesEventPageCampaign,
    GetNewArticlesGetNewArticlesEventPageContentModules,
    GetNewArticlesGetNewArticlesEventPageContentModulesBanners,
    GetNewArticlesGetNewArticlesEventPageContentModulesBannersPage,
    GetNewArticlesGetNewArticlesEventPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesEventPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesEventPageContentModulesLocations,
    GetNewArticlesGetNewArticlesEventPageContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteLogo,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageCampaign,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageContentModules,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageEvent,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageMinisite,
    GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteSponsors,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEventsPage,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesEventPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesEventPageContentModulesSections,
    GetNewArticlesGetNewArticlesEventPageContentModulesSectionsLinks,
    GetNewArticlesGetNewArticlesEventPageContentModulesSlides,
    GetNewArticlesGetNewArticlesEventPageContentModulesVideos,
    GetNewArticlesGetNewArticlesEventPageContentModulesVideosThumbnailImage,
    GetNewArticlesGetNewArticlesEventPageEvent,
    GetNewArticlesGetNewArticlesEventPageEventCircuits,
    GetNewArticlesGetNewArticlesEventPageEventPage,
    GetNewArticlesGetNewArticlesEventPageEventPageCampaign,
    GetNewArticlesGetNewArticlesEventPageEventPageContentModules,
    GetNewArticlesGetNewArticlesEventPageEventPageEvent,
    GetNewArticlesGetNewArticlesEventPageEventPageMinisite,
    GetNewArticlesGetNewArticlesEventPageMinisite,
    GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesEventPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesEventPageMinisiteLogo,
    GetNewArticlesGetNewArticlesEventPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesEventPageMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesEventPageMinisiteSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStats,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResultsDetails,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesBannersPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesBannersPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSectionsLinks,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesVideosThumbnailImage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedDisciplineStats,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsRecords,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResults,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResults,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsCompetitor,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsCompetitorTeamMembers,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsDetails,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsStartList,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsStartListCompetitor,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsTimetable,
    GetNewArticlesGetNewArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetNewArticlesGetNewArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedEventsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesBannersPage,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageCampaign,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageContentModules,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageEvent,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageMinisite,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSectionsLinks,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesVideosThumbnailImage,
    GetNewArticlesGetNewArticlesRelatedEventsPageEvent,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventPage,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedEventsPageEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocationsLocation,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEventPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEventPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinksFile,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinksPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageCampaign,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModules,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesBanners,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesFeatureLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesLifestyleLinks,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesLocations,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesMinisitePage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedArticles,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedCompetitors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedDiscipline,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedEvents,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedMedia,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedVideo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesSections,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesSlides,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesVideos,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEvent,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEventCircuits,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEventPage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisite,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsors,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo,
    GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo,
)
from .get_new_medias import GetNewMedias, GetNewMediasGetNewMedias
from .get_news_ticker import GetNewsTicker, GetNewsTickerGetNewsTicker
from .get_on_this_day import (
    GetOnThisDay,
    GetOnThisDayGetOnThisDay,
    GetOnThisDayGetOnThisDayResults,
)
from .get_page import (
    GetPage,
    GetPageGetPage,
    GetPageGetPageCampaign,
    GetPageGetPageContentModules,
    GetPageGetPageContentModulesBanners,
    GetPageGetPageContentModulesBannersPage,
    GetPageGetPageContentModulesBannersPageCampaign,
    GetPageGetPageContentModulesBannersPageContentModules,
    GetPageGetPageContentModulesBannersPageContentModulesBanners,
    GetPageGetPageContentModulesBannersPageContentModulesFeatureLinks,
    GetPageGetPageContentModulesBannersPageContentModulesLifestyleLinks,
    GetPageGetPageContentModulesBannersPageContentModulesLocations,
    GetPageGetPageContentModulesBannersPageContentModulesMinisite,
    GetPageGetPageContentModulesBannersPageContentModulesMinisitePage,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedArticles,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedEvents,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedMedia,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedVideo,
    GetPageGetPageContentModulesBannersPageContentModulesRelatedVideos,
    GetPageGetPageContentModulesBannersPageContentModulesSections,
    GetPageGetPageContentModulesBannersPageContentModulesSlides,
    GetPageGetPageContentModulesBannersPageContentModulesVideos,
    GetPageGetPageContentModulesBannersPageEvent,
    GetPageGetPageContentModulesBannersPageEventCircuits,
    GetPageGetPageContentModulesBannersPageEventPage,
    GetPageGetPageContentModulesBannersPageMinisite,
    GetPageGetPageContentModulesBannersPageMinisiteDefaultSponsors,
    GetPageGetPageContentModulesBannersPageMinisiteFeatureImage,
    GetPageGetPageContentModulesBannersPageMinisiteLogo,
    GetPageGetPageContentModulesBannersPageMinisiteSponsors,
    GetPageGetPageContentModulesFeatureLinks,
    GetPageGetPageContentModulesLifestyleLinks,
    GetPageGetPageContentModulesLocations,
    GetPageGetPageContentModulesLocationsLocation,
    GetPageGetPageContentModulesMinisite,
    GetPageGetPageContentModulesMinisiteDefaultSponsors,
    GetPageGetPageContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetPageGetPageContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetPageGetPageContentModulesMinisiteFeatureImage,
    GetPageGetPageContentModulesMinisiteLogo,
    GetPageGetPageContentModulesMinisitePage,
    GetPageGetPageContentModulesMinisitePageCampaign,
    GetPageGetPageContentModulesMinisitePageContentModules,
    GetPageGetPageContentModulesMinisitePageContentModulesBanners,
    GetPageGetPageContentModulesMinisitePageContentModulesBannersPage,
    GetPageGetPageContentModulesMinisitePageContentModulesFeatureLinks,
    GetPageGetPageContentModulesMinisitePageContentModulesLifestyleLinks,
    GetPageGetPageContentModulesMinisitePageContentModulesLocations,
    GetPageGetPageContentModulesMinisitePageContentModulesLocationsLocation,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisite,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisiteDefaultSponsors,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisiteFeatureImage,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisiteLogo,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisitePage,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageCampaign,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageContentModules,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageEvent,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageMinisite,
    GetPageGetPageContentModulesMinisitePageContentModulesMinisiteSponsors,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticles,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesContentModules,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesEvent,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedArticles,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedCompetitions,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedCompetitors,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedDiscipline,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedEvents,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedLinks,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedMedia,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedEvents,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedEventsCircuits,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedEventsPage,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedMedia,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedVideo,
    GetPageGetPageContentModulesMinisitePageContentModulesRelatedVideos,
    GetPageGetPageContentModulesMinisitePageContentModulesSections,
    GetPageGetPageContentModulesMinisitePageContentModulesSectionsLinks,
    GetPageGetPageContentModulesMinisitePageContentModulesSlides,
    GetPageGetPageContentModulesMinisitePageContentModulesVideos,
    GetPageGetPageContentModulesMinisitePageContentModulesVideosThumbnailImage,
    GetPageGetPageContentModulesMinisitePageEvent,
    GetPageGetPageContentModulesMinisitePageEventCircuits,
    GetPageGetPageContentModulesMinisitePageEventPage,
    GetPageGetPageContentModulesMinisitePageEventPageCampaign,
    GetPageGetPageContentModulesMinisitePageEventPageContentModules,
    GetPageGetPageContentModulesMinisitePageEventPageEvent,
    GetPageGetPageContentModulesMinisitePageEventPageMinisite,
    GetPageGetPageContentModulesMinisitePageMinisite,
    GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsors,
    GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsorsDarkBgLogo,
    GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsorsLightBgLogo,
    GetPageGetPageContentModulesMinisitePageMinisiteFeatureImage,
    GetPageGetPageContentModulesMinisitePageMinisiteLogo,
    GetPageGetPageContentModulesMinisitePageMinisiteSponsors,
    GetPageGetPageContentModulesMinisitePageMinisiteSponsorsDarkBgLogo,
    GetPageGetPageContentModulesMinisitePageMinisiteSponsorsLightBgLogo,
    GetPageGetPageContentModulesMinisiteSponsors,
    GetPageGetPageContentModulesMinisiteSponsorsDarkBgLogo,
    GetPageGetPageContentModulesMinisiteSponsorsLightBgLogo,
    GetPageGetPageContentModulesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesContentModules,
    GetPageGetPageContentModulesRelatedArticlesContentModulesLocations,
    GetPageGetPageContentModulesRelatedArticlesContentModulesLocationsLocation,
    GetPageGetPageContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetPageGetPageContentModulesRelatedArticlesEvent,
    GetPageGetPageContentModulesRelatedArticlesEventCircuits,
    GetPageGetPageContentModulesRelatedArticlesEventPage,
    GetPageGetPageContentModulesRelatedArticlesEventPageCampaign,
    GetPageGetPageContentModulesRelatedArticlesEventPageContentModules,
    GetPageGetPageContentModulesRelatedArticlesEventPageEvent,
    GetPageGetPageContentModulesRelatedArticlesEventPageMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesLocations,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesRelatedVideos,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEventCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEventPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStats,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEventsCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEventsPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitions,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEventCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEventPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEventCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEventPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageCampaign,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStats,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResultsResults,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResultsStartList,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedEvents,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageCampaign,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesBanners,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesLocations,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesSections,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesSlides,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesVideos,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEventCircuits,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEventPage,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteLogo,
    GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteSponsors,
    GetPageGetPageContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedEvents,
    GetPageGetPageContentModulesRelatedEventsCircuits,
    GetPageGetPageContentModulesRelatedEventsPage,
    GetPageGetPageContentModulesRelatedEventsPageCampaign,
    GetPageGetPageContentModulesRelatedEventsPageContentModules,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesBanners,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesFeatureLinks,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesLifestyleLinks,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesLocations,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesMinisite,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesMinisitePage,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedArticles,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedCompetitors,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedDiscipline,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedEvents,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedMedia,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedVideos,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesSections,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesSlides,
    GetPageGetPageContentModulesRelatedEventsPageContentModulesVideos,
    GetPageGetPageContentModulesRelatedEventsPageEvent,
    GetPageGetPageContentModulesRelatedEventsPageEventCircuits,
    GetPageGetPageContentModulesRelatedEventsPageEventPage,
    GetPageGetPageContentModulesRelatedEventsPageMinisite,
    GetPageGetPageContentModulesRelatedEventsPageMinisiteDefaultSponsors,
    GetPageGetPageContentModulesRelatedEventsPageMinisiteFeatureImage,
    GetPageGetPageContentModulesRelatedEventsPageMinisiteLogo,
    GetPageGetPageContentModulesRelatedEventsPageMinisiteSponsors,
    GetPageGetPageContentModulesRelatedMedia,
    GetPageGetPageContentModulesRelatedVideo,
    GetPageGetPageContentModulesRelatedVideos,
    GetPageGetPageContentModulesSections,
    GetPageGetPageContentModulesSectionsLinks,
    GetPageGetPageContentModulesSectionsLinksFile,
    GetPageGetPageContentModulesSectionsLinksPage,
    GetPageGetPageContentModulesSectionsLinksPageCampaign,
    GetPageGetPageContentModulesSectionsLinksPageContentModules,
    GetPageGetPageContentModulesSectionsLinksPageEvent,
    GetPageGetPageContentModulesSectionsLinksPageMinisite,
    GetPageGetPageContentModulesSlides,
    GetPageGetPageContentModulesVideos,
    GetPageGetPageContentModulesVideosThumbnailImage,
    GetPageGetPageEvent,
    GetPageGetPageEventCircuits,
    GetPageGetPageEventPage,
    GetPageGetPageEventPageCampaign,
    GetPageGetPageEventPageContentModules,
    GetPageGetPageEventPageContentModulesBanners,
    GetPageGetPageEventPageContentModulesBannersPage,
    GetPageGetPageEventPageContentModulesFeatureLinks,
    GetPageGetPageEventPageContentModulesLifestyleLinks,
    GetPageGetPageEventPageContentModulesLocations,
    GetPageGetPageEventPageContentModulesLocationsLocation,
    GetPageGetPageEventPageContentModulesMinisite,
    GetPageGetPageEventPageContentModulesMinisiteDefaultSponsors,
    GetPageGetPageEventPageContentModulesMinisiteFeatureImage,
    GetPageGetPageEventPageContentModulesMinisiteLogo,
    GetPageGetPageEventPageContentModulesMinisitePage,
    GetPageGetPageEventPageContentModulesMinisitePageCampaign,
    GetPageGetPageEventPageContentModulesMinisitePageContentModules,
    GetPageGetPageEventPageContentModulesMinisitePageEvent,
    GetPageGetPageEventPageContentModulesMinisitePageMinisite,
    GetPageGetPageEventPageContentModulesMinisiteSponsors,
    GetPageGetPageEventPageContentModulesRelatedArticles,
    GetPageGetPageEventPageContentModulesRelatedArticlesContentModules,
    GetPageGetPageEventPageContentModulesRelatedArticlesEvent,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedArticles,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedEvents,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedLinks,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedMedia,
    GetPageGetPageEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetPageGetPageEventPageContentModulesRelatedCompetitors,
    GetPageGetPageEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetPageGetPageEventPageContentModulesRelatedDiscipline,
    GetPageGetPageEventPageContentModulesRelatedEvents,
    GetPageGetPageEventPageContentModulesRelatedEventsCircuits,
    GetPageGetPageEventPageContentModulesRelatedEventsPage,
    GetPageGetPageEventPageContentModulesRelatedMedia,
    GetPageGetPageEventPageContentModulesRelatedVideo,
    GetPageGetPageEventPageContentModulesRelatedVideos,
    GetPageGetPageEventPageContentModulesSections,
    GetPageGetPageEventPageContentModulesSectionsLinks,
    GetPageGetPageEventPageContentModulesSlides,
    GetPageGetPageEventPageContentModulesVideos,
    GetPageGetPageEventPageContentModulesVideosThumbnailImage,
    GetPageGetPageEventPageEvent,
    GetPageGetPageEventPageEventCircuits,
    GetPageGetPageEventPageEventPage,
    GetPageGetPageEventPageEventPageCampaign,
    GetPageGetPageEventPageEventPageContentModules,
    GetPageGetPageEventPageEventPageEvent,
    GetPageGetPageEventPageEventPageMinisite,
    GetPageGetPageEventPageMinisite,
    GetPageGetPageEventPageMinisiteDefaultSponsors,
    GetPageGetPageEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetPageGetPageEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetPageGetPageEventPageMinisiteFeatureImage,
    GetPageGetPageEventPageMinisiteLogo,
    GetPageGetPageEventPageMinisiteSponsors,
    GetPageGetPageEventPageMinisiteSponsorsDarkBgLogo,
    GetPageGetPageEventPageMinisiteSponsorsLightBgLogo,
    GetPageGetPageMinisite,
    GetPageGetPageMinisiteDefaultSponsors,
    GetPageGetPageMinisiteDefaultSponsorsDarkBgLogo,
    GetPageGetPageMinisiteDefaultSponsorsLightBgLogo,
    GetPageGetPageMinisiteFeatureImage,
    GetPageGetPageMinisiteLogo,
    GetPageGetPageMinisiteSponsors,
    GetPageGetPageMinisiteSponsorsDarkBgLogo,
    GetPageGetPageMinisiteSponsorsLightBgLogo,
)
from .get_phases import GetPhases, GetPhasesGetPhases, GetPhasesGetPhasesUnits
from .get_placing_table import GetPlacingTable, GetPlacingTableGetPlacingTable
from .get_placing_table_details import (
    GetPlacingTableDetails,
    GetPlacingTableDetailsGetPlacingTableDetails,
)
from .get_pre_championship_highlights import (
    GetPreChampionshipHighlights,
    GetPreChampionshipHighlightsGetPreChampionshipHighlights,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembersTeamMembersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembersTeamMembersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembersTeamMembers,
    GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembersTeamMembersTeamMembers,
)
from .get_predictor_game_banner import (
    GetPredictorGameBanner,
    GetPredictorGameBannerGetPredictorGameBanner,
)
from .get_predictor_game_notification import (
    GetPredictorGameNotification,
    GetPredictorGameNotificationGetPredictorGameNotification,
)
from .get_random_world_ranking_discipline import (
    GetRandomWorldRankingDiscipline,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery,
    GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings,
)
from .get_ranking_groups import (
    GetRankingGroups,
    GetRankingGroupsGetRankingGroups,
    GetRankingGroupsGetRankingGroupsEvents,
)
from .get_ranking_score_calculation import (
    GetRankingScoreCalculation,
    GetRankingScoreCalculationGetRankingScoreCalculation,
    GetRankingScoreCalculationGetRankingScoreCalculationResults,
)
from .get_recent_results import (
    GetRecentResults,
    GetRecentResultsGetRecentResults,
    GetRecentResultsGetRecentResultsResults,
    GetRecentResultsGetRecentResultsResultsEvent,
    GetRecentResultsGetRecentResultsResultsEventCircuits,
    GetRecentResultsGetRecentResultsResultsEventPage,
    GetRecentResultsGetRecentResultsResultsEventPageCampaign,
    GetRecentResultsGetRecentResultsResultsEventPageContentModules,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesBanners,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesFeatureLinks,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesLifestyleLinks,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesLocations,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesMinisite,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesMinisitePage,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedArticles,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedCompetitors,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedDiscipline,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedEvents,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedMedia,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedVideo,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedVideos,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesSections,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesSlides,
    GetRecentResultsGetRecentResultsResultsEventPageContentModulesVideos,
    GetRecentResultsGetRecentResultsResultsEventPageEvent,
    GetRecentResultsGetRecentResultsResultsEventPageEventCircuits,
    GetRecentResultsGetRecentResultsResultsEventPageEventPage,
    GetRecentResultsGetRecentResultsResultsEventPageMinisite,
    GetRecentResultsGetRecentResultsResultsEventPageMinisiteDefaultSponsors,
    GetRecentResultsGetRecentResultsResultsEventPageMinisiteFeatureImage,
    GetRecentResultsGetRecentResultsResultsEventPageMinisiteLogo,
    GetRecentResultsGetRecentResultsResultsEventPageMinisiteSponsors,
)
from .get_records_by_category import (
    GetRecordsByCategory,
    GetRecordsByCategoryGetRecordsByCategory,
    GetRecordsByCategoryGetRecordsByCategoryCompetitor,
)
from .get_records_categories import (
    GetRecordsCategories,
    GetRecordsCategoriesGetRecordsCategories,
    GetRecordsCategoriesGetRecordsCategoriesItems,
    GetRecordsCategoriesGetRecordsCategoriesItemsItems,
    GetRecordsCategoriesGetRecordsCategoriesItemsItemsItems,
    GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItems,
    GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItemsItems,
)
from .get_records_detail_by_category import (
    GetRecordsDetailByCategory,
    GetRecordsDetailByCategoryGetRecordsDetailByCategory,
    GetRecordsDetailByCategoryGetRecordsDetailByCategoryResults,
    GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitor,
    GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitorTeamMembers,
)
from .get_records_detail_by_discipline import (
    GetRecordsDetailByDiscipline,
    GetRecordsDetailByDisciplineGetRecordsDetailByDiscipline,
    GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItems,
    GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitor,
    GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitorTeamMembers,
)
from .get_records_detail_by_progression import (
    GetRecordsDetailByProgression,
    GetRecordsDetailByProgressionGetRecordsDetailByProgression,
    GetRecordsDetailByProgressionGetRecordsDetailByProgressionDiscipline,
    GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntries,
    GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntriesCompetitor,
    GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntriesCompetitorTeamMembers,
)
from .get_records_discipline_list import (
    GetRecordsDisciplineList,
    GetRecordsDisciplineListGetRecordsDisciplineList,
    GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypes,
    GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypesDisciplines,
)
from .get_records_disciplines import (
    GetRecordsDisciplines,
    GetRecordsDisciplinesGetRecordsDisciplines,
)
from .get_result_info import GetResultInfo, GetResultInfoGetResultInfo
from .get_schedule import (
    GetSchedule,
    GetScheduleGetSchedule,
    GetScheduleGetScheduleDays,
    GetScheduleGetScheduleDaysChannels,
)
from .get_search_results import (
    GetSearchResults,
    GetSearchResultsGetSearchResults,
    GetSearchResultsGetSearchResultsItems,
)
from .get_single_competitor import (
    GetSingleCompetitor,
    GetSingleCompetitorGetSingleCompetitor,
    GetSingleCompetitorGetSingleCompetitorAthleteRepresentative,
    GetSingleCompetitorGetSingleCompetitorBasicData,
    GetSingleCompetitorGetSingleCompetitorBasicDataPrimaryMedia,
    GetSingleCompetitorGetSingleCompetitorHonours,
    GetSingleCompetitorGetSingleCompetitorHonoursResults,
    GetSingleCompetitorGetSingleCompetitorPersonalBests,
    GetSingleCompetitorGetSingleCompetitorPersonalBestsResults,
    GetSingleCompetitorGetSingleCompetitorPrimaryMedia,
    GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBests,
    GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBestsResults,
    GetSingleCompetitorGetSingleCompetitorResultsByDate,
    GetSingleCompetitorGetSingleCompetitorResultsByDateParameters,
    GetSingleCompetitorGetSingleCompetitorResultsByDateResultsByDate,
    GetSingleCompetitorGetSingleCompetitorResultsByYear,
    GetSingleCompetitorGetSingleCompetitorResultsByYearParameters,
    GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEvent,
    GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEventResults,
    GetSingleCompetitorGetSingleCompetitorSeasonsBests,
    GetSingleCompetitorGetSingleCompetitorSeasonsBestsParameters,
    GetSingleCompetitorGetSingleCompetitorSeasonsBestsResults,
    GetSingleCompetitorGetSingleCompetitorWorldRankings,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsBest,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsCurrent,
    GetSingleCompetitorGetSingleCompetitorWorldRankingsParameters,
)
from .get_single_competitor_all_time_personal_top_10 import (
    GetSingleCompetitorAllTimePersonalTop10,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters,
    GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results,
)
from .get_single_competitor_honour_summary import (
    GetSingleCompetitorHonourSummary,
    GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary,
)
from .get_single_competitor_major_championships import (
    GetSingleCompetitorMajorChampionships,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults,
    GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults,
)
from .get_single_competitor_results_by_limit import (
    GetSingleCompetitorResultsByLimit,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters,
    GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults,
)
from .get_single_competitor_results_date import (
    GetSingleCompetitorResultsDate,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDate,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateParameters,
    GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateResultsByDate,
)
from .get_single_competitor_results_discipline import (
    GetSingleCompetitorResultsDiscipline,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent,
    GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults,
)
from .get_single_competitor_season_bests import (
    GetSingleCompetitorSeasonBests,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters,
    GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults,
)
from .get_single_competitor_winning_streak import (
    GetSingleCompetitorWinningStreak,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks,
    GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults,
)
from .get_social_carousel import (
    GetSocialCarousel,
    GetSocialCarouselGetSocialCarousel,
    GetSocialCarouselGetSocialCarouselPrimaryMedia,
)
from .get_spikes import (
    GetSpikes,
    GetSpikesGetSpikes,
    GetSpikesGetSpikesPrimaryMedia,
    GetSpikesGetSpikesRelatedTags,
)
from .get_team_results import (
    GetTeamResults,
    GetTeamResultsGetTeamResults,
    GetTeamResultsGetTeamResultsTeamMembers,
)
from .get_team_scoring import (
    GetTeamScoring,
    GetTeamScoringGetTeamScoring,
    GetTeamScoringGetTeamScoringAthlete,
    GetTeamScoringGetTeamScoringAthleteDetail,
)
from .get_top_list import GetTopList, GetTopListGetTopList, GetTopListGetTopListPayload
from .get_top_lists_disciplines import (
    GetTopListsDisciplines,
    GetTopListsDisciplinesGetTopListsDisciplines,
)
from .get_top_panel import GetTopPanel, GetTopPanelGetTopPanel
from .get_top_rankings import (
    GetTopRankings,
    GetTopRankingsGetTopRankings,
    GetTopRankingsGetTopRankingsRankings,
    GetTopRankingsGetTopRankingsRankingsPrimaryMedia,
)
from .get_trending_athletes import (
    GetTrendingAthletes,
    GetTrendingAthletesGetTrendingAthletes,
    GetTrendingAthletesGetTrendingAthletesAthletesList,
    GetTrendingAthletesGetTrendingAthletesAthletesListPrimaryMedia,
    GetTrendingAthletesGetTrendingAthletesPrimaryMedia,
)
from .get_upcoming_competitions import (
    GetUpcomingCompetitions,
    GetUpcomingCompetitionsGetUpcomingCompetitions,
    GetUpcomingCompetitionsGetUpcomingCompetitionsCompetitions,
)
from .get_user import (
    GetUser,
    GetUserGetUser,
    GetUserGetUserSettings,
    GetUserGetUserSettingsFollowedCountries,
)
from .get_user_country import GetUserCountry, GetUserCountryGetUserCountry
from .get_users_votes import GetUsersVotes, GetUsersVotesGetUsersVotes
from .get_verification import GetVerification, GetVerificationGetVerification
from .get_video_by_id import GetVideoById, GetVideoByIdGetVideoById
from .get_video_list import GetVideoList, GetVideoListGetVideoList
from .get_video_playlist import GetVideoPlaylist, GetVideoPlaylistGetVideoPlaylist
from .get_videos_total_number import (
    GetVideosTotalNumber,
    GetVideosTotalNumberGetVideosTotalNumber,
)
from .get_vocabulary import GetVocabulary, GetVocabularyGetVocabulary
from .get_vote_options import GetVoteOptions, GetVoteOptionsGetVoteOptions
from .get_waw_competition import (
    GetWawCompetition,
    GetWawCompetitionGetWawCompetition,
    GetWawCompetitionGetWawCompetitionLastEvent,
    GetWawCompetitionGetWawCompetitionLastEventCircuits,
    GetWawCompetitionGetWawCompetitionLastEventPage,
    GetWawCompetitionGetWawCompetitionLastEventPageCampaign,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModules,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesBannersPage,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLocationsLocation,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteLogo,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageCampaign,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageContentModules,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageEvent,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageMinisite,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesContentModules,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesEvent,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedArticles,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedEvents,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedLinks,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedMedia,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEventsCircuits,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEventsPage,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSections,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSectionsLinks,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionLastEventPageContentModulesVideosThumbnailImage,
    GetWawCompetitionGetWawCompetitionLastEventPageEvent,
    GetWawCompetitionGetWawCompetitionLastEventPageEventCircuits,
    GetWawCompetitionGetWawCompetitionLastEventPageEventPage,
    GetWawCompetitionGetWawCompetitionLastEventPageEventPageCampaign,
    GetWawCompetitionGetWawCompetitionLastEventPageEventPageContentModules,
    GetWawCompetitionGetWawCompetitionLastEventPageEventPageEvent,
    GetWawCompetitionGetWawCompetitionLastEventPageEventPageMinisite,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisite,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionNextEvent,
    GetWawCompetitionGetWawCompetitionNextEventCircuits,
    GetWawCompetitionGetWawCompetitionNextEventPage,
    GetWawCompetitionGetWawCompetitionNextEventPageCampaign,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModules,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesBannersPage,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLocationsLocation,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteLogo,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageCampaign,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageContentModules,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageEvent,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageMinisite,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesContentModules,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesEvent,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedArticles,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedEvents,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedLinks,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedMedia,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEventsCircuits,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEventsPage,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSections,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSectionsLinks,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionNextEventPageContentModulesVideosThumbnailImage,
    GetWawCompetitionGetWawCompetitionNextEventPageEvent,
    GetWawCompetitionGetWawCompetitionNextEventPageEventCircuits,
    GetWawCompetitionGetWawCompetitionNextEventPageEventPage,
    GetWawCompetitionGetWawCompetitionNextEventPageEventPageCampaign,
    GetWawCompetitionGetWawCompetitionNextEventPageEventPageContentModules,
    GetWawCompetitionGetWawCompetitionNextEventPageEventPageEvent,
    GetWawCompetitionGetWawCompetitionNextEventPageEventPageMinisite,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisite,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionPage,
    GetWawCompetitionGetWawCompetitionPageCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionPageContentModulesBannersPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionPageContentModulesLocationsLocation,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesSections,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEventCircuits,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEventPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesLocations,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEventCircuits,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEventPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStats,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEventsCircuits,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEventsPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsCircuits,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageCampaign,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageContentModules,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageEvent,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageMinisite,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesSections,
    GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinks,
    GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinksFile,
    GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinksPage,
    GetWawCompetitionGetWawCompetitionPageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionPageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionPageContentModulesVideosThumbnailImage,
    GetWawCompetitionGetWawCompetitionPageEvent,
    GetWawCompetitionGetWawCompetitionPageEventCircuits,
    GetWawCompetitionGetWawCompetitionPageEventPage,
    GetWawCompetitionGetWawCompetitionPageEventPageCampaign,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModules,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesBanners,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesFeatureLinks,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesLifestyleLinks,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesLocations,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesMinisite,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesMinisitePage,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedArticles,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedCompetitors,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedDiscipline,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedEvents,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedMedia,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedVideo,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedVideos,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesSections,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesSlides,
    GetWawCompetitionGetWawCompetitionPageEventPageContentModulesVideos,
    GetWawCompetitionGetWawCompetitionPageEventPageEvent,
    GetWawCompetitionGetWawCompetitionPageEventPageEventCircuits,
    GetWawCompetitionGetWawCompetitionPageEventPageEventPage,
    GetWawCompetitionGetWawCompetitionPageEventPageMinisite,
    GetWawCompetitionGetWawCompetitionPageEventPageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionPageEventPageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionPageEventPageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionPageEventPageMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionPageMinisite,
    GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsors,
    GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawCompetitionGetWawCompetitionPageMinisiteFeatureImage,
    GetWawCompetitionGetWawCompetitionPageMinisiteLogo,
    GetWawCompetitionGetWawCompetitionPageMinisiteSponsors,
    GetWawCompetitionGetWawCompetitionPageMinisiteSponsorsDarkBgLogo,
    GetWawCompetitionGetWawCompetitionPageMinisiteSponsorsLightBgLogo,
)
from .get_waw_competition_events_organizer_details import (
    GetWawCompetitionEventsOrganizerDetails,
    GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails,
    GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails,
)
from .get_waw_event import (
    GetWawEvent,
    GetWawEventGetWawEvent,
    GetWawEventGetWawEventCircuits,
    GetWawEventGetWawEventPage,
    GetWawEventGetWawEventPageCampaign,
    GetWawEventGetWawEventPageContentModules,
    GetWawEventGetWawEventPageContentModulesBanners,
    GetWawEventGetWawEventPageContentModulesBannersPage,
    GetWawEventGetWawEventPageContentModulesBannersPageCampaign,
    GetWawEventGetWawEventPageContentModulesBannersPageContentModules,
    GetWawEventGetWawEventPageContentModulesBannersPageEvent,
    GetWawEventGetWawEventPageContentModulesBannersPageMinisite,
    GetWawEventGetWawEventPageContentModulesFeatureLinks,
    GetWawEventGetWawEventPageContentModulesLifestyleLinks,
    GetWawEventGetWawEventPageContentModulesLocations,
    GetWawEventGetWawEventPageContentModulesLocationsLocation,
    GetWawEventGetWawEventPageContentModulesMinisite,
    GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsors,
    GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsorsDarkBgLogo,
    GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsorsLightBgLogo,
    GetWawEventGetWawEventPageContentModulesMinisiteFeatureImage,
    GetWawEventGetWawEventPageContentModulesMinisiteLogo,
    GetWawEventGetWawEventPageContentModulesMinisitePage,
    GetWawEventGetWawEventPageContentModulesMinisitePageCampaign,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModules,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesBanners,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesFeatureLinks,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesLifestyleLinks,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesLocations,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesMinisite,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesMinisitePage,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedArticles,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedCompetitors,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedDiscipline,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedEvents,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedMedia,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedVideo,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedVideos,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesSections,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesSlides,
    GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesVideos,
    GetWawEventGetWawEventPageContentModulesMinisitePageEvent,
    GetWawEventGetWawEventPageContentModulesMinisitePageEventCircuits,
    GetWawEventGetWawEventPageContentModulesMinisitePageEventPage,
    GetWawEventGetWawEventPageContentModulesMinisitePageMinisite,
    GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteDefaultSponsors,
    GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteFeatureImage,
    GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteLogo,
    GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteSponsors,
    GetWawEventGetWawEventPageContentModulesMinisiteSponsors,
    GetWawEventGetWawEventPageContentModulesMinisiteSponsorsDarkBgLogo,
    GetWawEventGetWawEventPageContentModulesMinisiteSponsorsLightBgLogo,
    GetWawEventGetWawEventPageContentModulesRelatedArticles,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModules,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesLocations,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesRelatedVideo,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesRelatedVideos,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesEvent,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesEventCircuits,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesEventPage,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticles,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesContentModules,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesEvent,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsPage,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStats,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsResults,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEvents,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEventsCircuits,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEventsPage,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedLinks,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMedia,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesEvent,
    GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite,
    GetWawEventGetWawEventPageContentModulesRelatedCompetitors,
    GetWawEventGetWawEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawEventGetWawEventPageContentModulesRelatedDiscipline,
    GetWawEventGetWawEventPageContentModulesRelatedEvents,
    GetWawEventGetWawEventPageContentModulesRelatedEventsCircuits,
    GetWawEventGetWawEventPageContentModulesRelatedEventsPage,
    GetWawEventGetWawEventPageContentModulesRelatedEventsPageCampaign,
    GetWawEventGetWawEventPageContentModulesRelatedEventsPageContentModules,
    GetWawEventGetWawEventPageContentModulesRelatedEventsPageEvent,
    GetWawEventGetWawEventPageContentModulesRelatedEventsPageMinisite,
    GetWawEventGetWawEventPageContentModulesRelatedMedia,
    GetWawEventGetWawEventPageContentModulesRelatedVideo,
    GetWawEventGetWawEventPageContentModulesRelatedVideos,
    GetWawEventGetWawEventPageContentModulesSections,
    GetWawEventGetWawEventPageContentModulesSectionsLinks,
    GetWawEventGetWawEventPageContentModulesSectionsLinksFile,
    GetWawEventGetWawEventPageContentModulesSectionsLinksPage,
    GetWawEventGetWawEventPageContentModulesSlides,
    GetWawEventGetWawEventPageContentModulesVideos,
    GetWawEventGetWawEventPageContentModulesVideosThumbnailImage,
    GetWawEventGetWawEventPageEvent,
    GetWawEventGetWawEventPageEventCircuits,
    GetWawEventGetWawEventPageEventPage,
    GetWawEventGetWawEventPageEventPageCampaign,
    GetWawEventGetWawEventPageEventPageContentModules,
    GetWawEventGetWawEventPageEventPageContentModulesBanners,
    GetWawEventGetWawEventPageEventPageContentModulesFeatureLinks,
    GetWawEventGetWawEventPageEventPageContentModulesLifestyleLinks,
    GetWawEventGetWawEventPageEventPageContentModulesLocations,
    GetWawEventGetWawEventPageEventPageContentModulesMinisite,
    GetWawEventGetWawEventPageEventPageContentModulesMinisitePage,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedArticles,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedCompetitors,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedDiscipline,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedEvents,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedMedia,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedVideo,
    GetWawEventGetWawEventPageEventPageContentModulesRelatedVideos,
    GetWawEventGetWawEventPageEventPageContentModulesSections,
    GetWawEventGetWawEventPageEventPageContentModulesSlides,
    GetWawEventGetWawEventPageEventPageContentModulesVideos,
    GetWawEventGetWawEventPageEventPageEvent,
    GetWawEventGetWawEventPageEventPageEventCircuits,
    GetWawEventGetWawEventPageEventPageEventPage,
    GetWawEventGetWawEventPageEventPageMinisite,
    GetWawEventGetWawEventPageEventPageMinisiteDefaultSponsors,
    GetWawEventGetWawEventPageEventPageMinisiteFeatureImage,
    GetWawEventGetWawEventPageEventPageMinisiteLogo,
    GetWawEventGetWawEventPageEventPageMinisiteSponsors,
    GetWawEventGetWawEventPageMinisite,
    GetWawEventGetWawEventPageMinisiteDefaultSponsors,
    GetWawEventGetWawEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawEventGetWawEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawEventGetWawEventPageMinisiteFeatureImage,
    GetWawEventGetWawEventPageMinisiteLogo,
    GetWawEventGetWawEventPageMinisiteSponsors,
    GetWawEventGetWawEventPageMinisiteSponsorsDarkBgLogo,
    GetWawEventGetWawEventPageMinisiteSponsorsLightBgLogo,
)
from .get_waw_event_country_list import (
    GetWawEventCountryList,
    GetWawEventCountryListGetWawEventCountryList,
    GetWawEventCountryListGetWawEventCountryListCountries,
)
from .get_waw_medal_details import (
    GetWawMedalDetails,
    GetWawMedalDetailsGetWawMedalDetails,
    GetWawMedalDetailsGetWawMedalDetailsCompetitor,
    GetWawMedalDetailsGetWawMedalDetailsDiscipline,
)
from .get_waw_menu import (
    GetWawMenu,
    GetWawMenuGetWawMenu,
    GetWawMenuGetWawMenuEvent,
    GetWawMenuGetWawMenuEventCircuits,
    GetWawMenuGetWawMenuEventPage,
    GetWawMenuGetWawMenuEventPageCampaign,
    GetWawMenuGetWawMenuEventPageContentModules,
    GetWawMenuGetWawMenuEventPageContentModulesBanners,
    GetWawMenuGetWawMenuEventPageContentModulesBannersPage,
    GetWawMenuGetWawMenuEventPageContentModulesFeatureLinks,
    GetWawMenuGetWawMenuEventPageContentModulesLifestyleLinks,
    GetWawMenuGetWawMenuEventPageContentModulesLocations,
    GetWawMenuGetWawMenuEventPageContentModulesLocationsLocation,
    GetWawMenuGetWawMenuEventPageContentModulesMinisite,
    GetWawMenuGetWawMenuEventPageContentModulesMinisiteDefaultSponsors,
    GetWawMenuGetWawMenuEventPageContentModulesMinisiteFeatureImage,
    GetWawMenuGetWawMenuEventPageContentModulesMinisiteLogo,
    GetWawMenuGetWawMenuEventPageContentModulesMinisitePage,
    GetWawMenuGetWawMenuEventPageContentModulesMinisitePageCampaign,
    GetWawMenuGetWawMenuEventPageContentModulesMinisitePageContentModules,
    GetWawMenuGetWawMenuEventPageContentModulesMinisitePageEvent,
    GetWawMenuGetWawMenuEventPageContentModulesMinisitePageMinisite,
    GetWawMenuGetWawMenuEventPageContentModulesMinisiteSponsors,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticles,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesContentModules,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesEvent,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedArticles,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedEvents,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedLinks,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedMedia,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedCompetitors,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedDiscipline,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedEvents,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedEventsCircuits,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedEventsPage,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedMedia,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedVideo,
    GetWawMenuGetWawMenuEventPageContentModulesRelatedVideos,
    GetWawMenuGetWawMenuEventPageContentModulesSections,
    GetWawMenuGetWawMenuEventPageContentModulesSectionsLinks,
    GetWawMenuGetWawMenuEventPageContentModulesSlides,
    GetWawMenuGetWawMenuEventPageContentModulesVideos,
    GetWawMenuGetWawMenuEventPageContentModulesVideosThumbnailImage,
    GetWawMenuGetWawMenuEventPageEvent,
    GetWawMenuGetWawMenuEventPageEventCircuits,
    GetWawMenuGetWawMenuEventPageEventPage,
    GetWawMenuGetWawMenuEventPageEventPageCampaign,
    GetWawMenuGetWawMenuEventPageEventPageContentModules,
    GetWawMenuGetWawMenuEventPageEventPageEvent,
    GetWawMenuGetWawMenuEventPageEventPageMinisite,
    GetWawMenuGetWawMenuEventPageMinisite,
    GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsors,
    GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawMenuGetWawMenuEventPageMinisiteFeatureImage,
    GetWawMenuGetWawMenuEventPageMinisiteLogo,
    GetWawMenuGetWawMenuEventPageMinisiteSponsors,
    GetWawMenuGetWawMenuEventPageMinisiteSponsorsDarkBgLogo,
    GetWawMenuGetWawMenuEventPageMinisiteSponsorsLightBgLogo,
    GetWawMenuGetWawMenuItems,
    GetWawMenuGetWawMenuItemsItems,
    GetWawMenuGetWawMenuItemsItemsItems,
    GetWawMenuGetWawMenuItemsItemsItemsItems,
    GetWawMenuGetWawMenuItemsItemsItemsItemsItems,
    GetWawMenuGetWawMenuItemsItemsItemsItemsPage,
    GetWawMenuGetWawMenuItemsItemsItemsPage,
    GetWawMenuGetWawMenuItemsItemsItemsPageCampaign,
    GetWawMenuGetWawMenuItemsItemsItemsPageContentModules,
    GetWawMenuGetWawMenuItemsItemsItemsPageEvent,
    GetWawMenuGetWawMenuItemsItemsItemsPageMinisite,
    GetWawMenuGetWawMenuItemsItemsPage,
    GetWawMenuGetWawMenuItemsItemsPageCampaign,
    GetWawMenuGetWawMenuItemsItemsPageContentModules,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesBanners,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesFeatureLinks,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesLifestyleLinks,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesLocations,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesMinisite,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesMinisitePage,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedArticles,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedCompetitors,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedDiscipline,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedEvents,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedMedia,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedVideo,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedVideos,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesSections,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesSlides,
    GetWawMenuGetWawMenuItemsItemsPageContentModulesVideos,
    GetWawMenuGetWawMenuItemsItemsPageEvent,
    GetWawMenuGetWawMenuItemsItemsPageEventCircuits,
    GetWawMenuGetWawMenuItemsItemsPageEventPage,
    GetWawMenuGetWawMenuItemsItemsPageMinisite,
    GetWawMenuGetWawMenuItemsItemsPageMinisiteDefaultSponsors,
    GetWawMenuGetWawMenuItemsItemsPageMinisiteFeatureImage,
    GetWawMenuGetWawMenuItemsItemsPageMinisiteLogo,
    GetWawMenuGetWawMenuItemsItemsPageMinisiteSponsors,
    GetWawMenuGetWawMenuItemsPage,
    GetWawMenuGetWawMenuItemsPageCampaign,
    GetWawMenuGetWawMenuItemsPageContentModules,
    GetWawMenuGetWawMenuItemsPageContentModulesBanners,
    GetWawMenuGetWawMenuItemsPageContentModulesBannersPage,
    GetWawMenuGetWawMenuItemsPageContentModulesFeatureLinks,
    GetWawMenuGetWawMenuItemsPageContentModulesLifestyleLinks,
    GetWawMenuGetWawMenuItemsPageContentModulesLocations,
    GetWawMenuGetWawMenuItemsPageContentModulesLocationsLocation,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisite,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisiteDefaultSponsors,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisiteFeatureImage,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisiteLogo,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisitePage,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageCampaign,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageContentModules,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageEvent,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageMinisite,
    GetWawMenuGetWawMenuItemsPageContentModulesMinisiteSponsors,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticles,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesContentModules,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesEvent,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedArticles,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedCompetitions,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedCompetitors,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedDiscipline,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedEvents,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedLinks,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedMedia,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedMinisitePages,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedCompetitors,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedCompetitorsPrimaryMedia,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedDiscipline,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedEvents,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedEventsCircuits,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedEventsPage,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedMedia,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedVideo,
    GetWawMenuGetWawMenuItemsPageContentModulesRelatedVideos,
    GetWawMenuGetWawMenuItemsPageContentModulesSections,
    GetWawMenuGetWawMenuItemsPageContentModulesSectionsLinks,
    GetWawMenuGetWawMenuItemsPageContentModulesSlides,
    GetWawMenuGetWawMenuItemsPageContentModulesVideos,
    GetWawMenuGetWawMenuItemsPageContentModulesVideosThumbnailImage,
    GetWawMenuGetWawMenuItemsPageEvent,
    GetWawMenuGetWawMenuItemsPageEventCircuits,
    GetWawMenuGetWawMenuItemsPageEventPage,
    GetWawMenuGetWawMenuItemsPageEventPageCampaign,
    GetWawMenuGetWawMenuItemsPageEventPageContentModules,
    GetWawMenuGetWawMenuItemsPageEventPageEvent,
    GetWawMenuGetWawMenuItemsPageEventPageMinisite,
    GetWawMenuGetWawMenuItemsPageMinisite,
    GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsors,
    GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsorsDarkBgLogo,
    GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsorsLightBgLogo,
    GetWawMenuGetWawMenuItemsPageMinisiteFeatureImage,
    GetWawMenuGetWawMenuItemsPageMinisiteLogo,
    GetWawMenuGetWawMenuItemsPageMinisiteSponsors,
    GetWawMenuGetWawMenuItemsPageMinisiteSponsorsDarkBgLogo,
    GetWawMenuGetWawMenuItemsPageMinisiteSponsorsLightBgLogo,
)
from .get_waw_placing_table_details import (
    GetWawPlacingTableDetails,
    GetWawPlacingTableDetailsGetWawPlacingTableDetails,
    GetWawPlacingTableDetailsGetWawPlacingTableDetailsCompetitor,
    GetWawPlacingTableDetailsGetWawPlacingTableDetailsDiscipline,
)
from .get_waw_placing_tables import (
    GetWawPlacingTables,
    GetWawPlacingTablesGetWawPlacingTables,
)
from .get_where_to_watch import (
    GetWhereToWatch,
    GetWhereToWatchGetWhereToWatch,
    GetWhereToWatchGetWhereToWatchEventLevelGeneralChannels,
    GetWhereToWatchGetWhereToWatchEventLevelGeneralChannelsDays,
)
from .get_world_leading_competitors import (
    GetWorldLeadingCompetitors,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitors,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitorTeamMembers,
    GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia,
)
from .get_world_ranking import GetWorldRanking, GetWorldRankingGetWorldRanking
from .get_world_rankings import (
    GetWorldRankings,
    GetWorldRankingsGetWorldRankings,
    GetWorldRankingsGetWorldRankingsParameters,
    GetWorldRankingsGetWorldRankingsRankings,
)
from .get_world_rankings_changes import (
    GetWorldRankingsChanges,
    GetWorldRankingsChangesGetWorldRankingsChanges,
    GetWorldRankingsChangesGetWorldRankingsChangesChanges,
)
from .head_to_head import (
    HeadToHead,
    HeadToHeadHeadToHead,
    HeadToHeadHeadToHeadDisciplines,
    HeadToHeadHeadToHeadOpponents,
    HeadToHeadHeadToHeadParameters,
    HeadToHeadHeadToHeadResults,
    HeadToHeadHeadToHeadResultsResults,
)
from .input_types import (
    AAapiQuery,
    ChunkType,
    ClientMetadataInput,
    CompetitorInput,
    CompetitorQueryInput,
    EventInput,
    FlashInterviewInput,
    LiveCombinedSummaryDetailInput,
    LivePhaseSummaryInput,
    LivePhaseSummaryQuery,
    LiveResultInput,
    LiveResultTeamMemberInput,
    MedalDetailInput,
    MedalInput,
    MedalMutationInput,
    PhaseInput,
    PhaseQueryInput,
    PlacingTableDetailInput,
    PlacingTableInput,
    PreviousMedalQuery,
    TeamQuery,
    TeamScoringInput,
    TeamStandingsInput,
    UnitInput,
)
from .my_athletes import (
    MyAthletes,
    MyAthletesMyAthletes,
    MyAthletesMyAthletesPrimaryMedia,
)
from .previous_medalists import PreviousMedalists, PreviousMedalistsPreviousMedalists
from .records_by_event import (
    RecordsByEvent,
    RecordsByEventRecordsByEvent,
    RecordsByEventRecordsByEventCompetitor,
)
from .results_by_athlete import (
    ResultsByAthlete,
    ResultsByAthleteResultsByAthlete,
    ResultsByAthleteResultsByAthleteParameters,
    ResultsByAthleteResultsByAthleteResults,
    ResultsByAthleteResultsByAthleteResultsAthlete,
    ResultsByAthleteResultsByAthleteResultsTeam,
    ResultsByAthleteResultsByAthleteResultsTeamTeamMembers,
)
from .search_athletes import (
    SearchAthletes,
    SearchAthletesSearchAthletes,
    SearchAthletesSearchAthletesCompetitionEntries,
    SearchAthletesSearchAthletesCompetitionEntriesDiscipline,
    SearchAthletesSearchAthletesDisciplines,
    SearchAthletesSearchAthletesPrimaryMedia,
)
from .search_competitors import SearchCompetitors, SearchCompetitorsSearchCompetitors
from .sign_cookies import SignCookies, SignCookiesSignCookies
from .team_profile import (
    TeamProfile,
    TeamProfileTeamProfile,
    TeamProfileTeamProfilePersonalBestInfo,
    TeamProfileTeamProfilePersonalBests,
    TeamProfileTeamProfilePersonalBestsDiscipline,
    TeamProfileTeamProfilePersonalHonour,
    TeamProfileTeamProfilePersonalHonourDiscipline,
    TeamProfileTeamProfilePersonalHonourInfo,
)
from .team_standings import (
    TeamStandings,
    TeamStandingsTeamStandings,
    TeamStandingsTeamStandingsRelatedAthlete,
    TeamStandingsTeamStandingsRelatedAthleteDetail,
)
from .verify_captcha_token import (
    VerifyCaptchaToken,
    VerifyCaptchaTokenVerifyCaptchaToken,
)
from .verify_h_captcha_token import (
    VerifyHCaptchaToken,
    VerifyHCaptchaTokenVerifyHCaptchaToken,
)

__all__ = [
    "AAapiQuery",
    "AirQualityDeviceElementReads",
    "AirQualityDeviceElementReadsAirQualityDeviceElementReads",
    "AirQualityDeviceFilter",
    "AirQualityDevices",
    "AirQualityDevicesAirQualityDevices",
    "AirQualityDevicesAirQualityDevicesLocation",
    "AsyncBaseClient",
    "BaseModel",
    "CarouselTypeEnum",
    "ChunkType",
    "ClientMetadataInput",
    "CompetitionDocument",
    "CompetitionDocumentCompetitionDocument",
    "CompetitionsByCountry",
    "CompetitionsByCountryCompetitionsByCountry",
    "CompetitionsByCountryCompetitionsByCountryParameters",
    "CompetitionsByCountryCompetitionsByCountryResults",
    "CompetitorInput",
    "CompetitorQueryInput",
    "CountriesByEventId",
    "CountriesByEventIdCountriesByEventId",
    "CurrentRecordHolder",
    "CurrentRecordHolderCurrentRecordHolder",
    "CurrentRecordHolderCurrentRecordHolderCompetitor",
    "DisciplinesByEventId",
    "DisciplinesByEventIdDisciplinesByEventId",
    "EventInput",
    "EventMedia",
    "EventMediaEventMedia",
    "EventMediaEventMediaMedia",
    "EventMediaEventMediaQuery",
    "FlashInterviewInput",
    "GenderType",
    "GetAllCompetitions",
    "GetAllCompetitionsGetAllCompetitions",
    "GetAllCompetitionsGetAllCompetitionsAllEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsLastEventPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsNextEventPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesBannersPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesLocationsLocation",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisitePageMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEventsCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedEventsPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSectionsLinks",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageContentModulesVideosThumbnailImage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsorsDarkBgLogo",
    "GetAllCompetitionsGetAllCompetitionsAllEventsPageMinisiteSponsorsLightBgLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventLastEventPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventNextEventPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesBanners",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesBannersPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesFeatureLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLifestyleLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLocations",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesLocationsLocation",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisitePageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedCompetitors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedDiscipline",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEvents",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEventsCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedEventsPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedMedia",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedVideo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesRelatedVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSections",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSectionsLinks",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesSlides",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesVideos",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageContentModulesVideosThumbnailImage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventCircuits",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageCampaign",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageContentModules",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageEvent",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisite",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteFeatureImage",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsors",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsorsDarkBgLogo",
    "GetAllCompetitionsGetAllCompetitionsPageNextEventPageMinisiteSponsorsLightBgLogo",
    "GetAllEventPhasesByDiscipline",
    "GetAllEventPhasesByDisciplineGetAllEventPhasesByDiscipline",
    "GetAllEventPhasesByDisciplineGetAllEventPhasesByDisciplineDiscipline",
    "GetAllGoldTourEvents",
    "GetAllGoldTourEventsGetAllGoldTourEvents",
    "GetAllGoldTourEventsGetAllGoldTourEventsEvents",
    "GetAllSchedules",
    "GetAllSchedulesGetAllSchedules",
    "GetAllSchedulesGetAllSchedulesDays",
    "GetAllSchedulesGetAllSchedulesDaysChannels",
    "GetAllTimeList",
    "GetAllTimeListGetAllTimeList",
    "GetAllTimeListGetAllTimeListPayload",
    "GetAppearance",
    "GetAppearanceGetAppearance",
    "GetAppearanceGetAppearanceDefaultSponsors",
    "GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo",
    "GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo",
    "GetAppearanceGetAppearanceFeatureImage",
    "GetAppearanceGetAppearanceLogo",
    "GetAppearanceGetAppearanceSponsors",
    "GetAppearanceGetAppearanceSponsorsDarkBgLogo",
    "GetAppearanceGetAppearanceSponsorsLightBgLogo",
    "GetArticle",
    "GetArticleGetArticle",
    "GetArticleGetArticleLocation",
    "GetArticleGetArticleRelatedArticles",
    "GetArticleGetArticleRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEvent",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEventCircuits",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageEventPage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitions",
    "GetArticleGetArticleRelatedCompetitionsLastEvent",
    "GetArticleGetArticleRelatedCompetitionsLastEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsLastEventPage",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageCampaign",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModules",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesBanners",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesLocations",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesMinisite",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesSections",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesSlides",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageContentModulesVideos",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageEvent",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageEventPage",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageMinisite",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteLogo",
    "GetArticleGetArticleRelatedCompetitionsLastEventPageMinisiteSponsors",
    "GetArticleGetArticleRelatedCompetitionsNextEvent",
    "GetArticleGetArticleRelatedCompetitionsNextEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsNextEventPage",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageCampaign",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModules",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesBanners",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesLocations",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesMinisite",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesSections",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesSlides",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageContentModulesVideos",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageEvent",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageEventPage",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageMinisite",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteLogo",
    "GetArticleGetArticleRelatedCompetitionsNextEventPageMinisiteSponsors",
    "GetArticleGetArticleRelatedCompetitionsPage",
    "GetArticleGetArticleRelatedCompetitionsPageCampaign",
    "GetArticleGetArticleRelatedCompetitionsPageContentModules",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesBanners",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesBannersPage",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesLocations",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesLocationsLocation",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisite",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteLogo",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePage",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageEvent",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesMinisiteSponsors",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedEventsPage",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesSections",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesSectionsLinks",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesSlides",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesVideos",
    "GetArticleGetArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage",
    "GetArticleGetArticleRelatedCompetitionsPageEvent",
    "GetArticleGetArticleRelatedCompetitionsPageEventCircuits",
    "GetArticleGetArticleRelatedCompetitionsPageEventPage",
    "GetArticleGetArticleRelatedCompetitionsPageEventPageCampaign",
    "GetArticleGetArticleRelatedCompetitionsPageEventPageContentModules",
    "GetArticleGetArticleRelatedCompetitionsPageEventPageEvent",
    "GetArticleGetArticleRelatedCompetitionsPageEventPageMinisite",
    "GetArticleGetArticleRelatedCompetitionsPageMinisite",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteFeatureImage",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteLogo",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsors",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo",
    "GetArticleGetArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo",
    "GetArticleGetArticleRelatedCompetitors",
    "GetArticleGetArticleRelatedCompetitorsRelatedMedia",
    "GetArticleGetArticleRelatedDiscipline",
    "GetArticleGetArticleRelatedMedia",
    "GetArticleLocations",
    "GetArticleLocationsGetArticleLocations",
    "GetArticles",
    "GetArticlesGetArticles",
    "GetArticlesGetArticlesLocation",
    "GetArticlesGetArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesLocation",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSections",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEventCircuits",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageEventPage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedCompetitionsLastEvent",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesBanners",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesFeatureLinks",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesLifestyleLinks",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesLocations",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesMinisitePage",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedArticles",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedEvents",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideo",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideos",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesSections",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesSlides",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageContentModulesVideos",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteDefaultSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteFeatureImage",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteLogo",
    "GetArticlesGetArticlesRelatedCompetitionsLastEventPageMinisiteSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsNextEvent",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesBanners",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesFeatureLinks",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesLifestyleLinks",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesLocations",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesMinisitePage",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedArticles",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedEvents",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideo",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideos",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesSections",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesSlides",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageContentModulesVideos",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteDefaultSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteFeatureImage",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteLogo",
    "GetArticlesGetArticlesRelatedCompetitionsNextEventPageMinisiteSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsPage",
    "GetArticlesGetArticlesRelatedCompetitionsPageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesBannersPage",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesLocationsLocation",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteFeatureImage",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteLogo",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisitePageMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesMinisiteSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesEvent",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEventsCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedEventsPage",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSections",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSectionsLinks",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetArticlesGetArticlesRelatedCompetitionsPageContentModulesVideosThumbnailImage",
    "GetArticlesGetArticlesRelatedCompetitionsPageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventCircuits",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventPage",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventPageCampaign",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventPageContentModules",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventPageEvent",
    "GetArticlesGetArticlesRelatedCompetitionsPageEventPageMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisite",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo",
    "GetArticlesGetArticlesRelatedCompetitionsPageMinisiteSponsorsLightBgLogo",
    "GetArticlesGetArticlesRelatedCompetitors",
    "GetArticlesGetArticlesRelatedCompetitorsRelatedMedia",
    "GetArticlesGetArticlesRelatedDiscipline",
    "GetArticlesGetArticlesRelatedMedia",
    "GetAsset",
    "GetAssetGetAsset",
    "GetAssetGetAssetCampaign",
    "GetAssetGetAssetDocument",
    "GetAssetGetAssetFilters",
    "GetAssetGetAssetFiltersType",
    "GetAssetGetAssetFiltersTypeFilters",
    "GetAssetGetAssetFiltersTypeFiltersType",
    "GetAssetGetAssetFiltersTypeFiltersTypeFilters",
    "GetAssetGetAssetThumbnailFeatureImage",
    "GetAssets",
    "GetAssetsDates",
    "GetAssetsDatesGetAssetsDates",
    "GetAssetsGetAssets",
    "GetAssetsGetAssetsCampaign",
    "GetAssetsGetAssetsDocument",
    "GetAssetsGetAssetsFilters",
    "GetAssetsGetAssetsFiltersType",
    "GetAssetsGetAssetsFiltersTypeFilters",
    "GetAssetsGetAssetsFiltersTypeFiltersType",
    "GetAssetsGetAssetsFiltersTypeFiltersTypeFilters",
    "GetAssetsGetAssetsThumbnailFeatureImage",
    "GetAssetsTotal",
    "GetAssetsTotalGetAssetsTotal",
    "GetAthlete",
    "GetAthleteGetAthlete",
    "GetAthleteGetAthletePrimaryMedia",
    "GetAthleteProfileAthleteRepresentative",
    "GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative",
    "GetAthleteRepresentativeAthleteSearch",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren",
    "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries",
    "GetAthleteRepresentativeDirectory",
    "GetAthleteRepresentativeDirectoryGetAthleteRepresentativeDirectory",
    "GetAthleteRepresentativeProfile",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist",
    "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes",
    "GetAthleteRepresentativeTopList",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist",
    "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes",
    "GetAthleteResults",
    "GetAthleteResultsGetAthleteResults",
    "GetAthleteResultsGetAthleteResultsTeamMembers",
    "GetBanners",
    "GetBannersGetBanners",
    "GetBannersGetBannersBannerItems",
    "GetBannersGetBannersBannerItemsPrimaryMedia",
    "GetCISCompetitorResDate",
    "GetCISCompetitorResDateGetCisCompetitorResDate",
    "GetCISCompetitorResDateGetCisCompetitorResDateParameters",
    "GetCISCompetitorResDateGetCisCompetitorResDateResultsByDate",
    "GetCISCompetitorResDisp",
    "GetCISCompetitorResDispGetCisCompetitorResDisp",
    "GetCISCompetitorResDispGetCisCompetitorResDispParameters",
    "GetCISCompetitorResDispGetCisCompetitorResDispResultsByDate",
    "GetCISCompetitorResDispGetCisCompetitorResDispResultsByEvent",
    "GetCISCompetitorResDispGetCisCompetitorResDispResultsByEventResults",
    "GetCISSingleCompetitor",
    "GetCISSingleCompetitorGetCisSingleCompetitor",
    "GetCISSingleCompetitorGetCisSingleCompetitorAthleteRepresentative",
    "GetCISSingleCompetitorGetCisSingleCompetitorBasicData",
    "GetCISSingleCompetitorGetCisSingleCompetitorHonours",
    "GetCISSingleCompetitorGetCisSingleCompetitorHonoursResults",
    "GetCISSingleCompetitorGetCisSingleCompetitorPersonalBests",
    "GetCISSingleCompetitorGetCisSingleCompetitorPersonalBestsResults",
    "GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBests",
    "GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBestsResults",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDate",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateParameters",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateResultsByDate",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYear",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearParameters",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEvent",
    "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEventResults",
    "GetCISSingleCompetitorGetCisSingleCompetitorRoadRaceLabelStatus",
    "GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBests",
    "GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsParameters",
    "GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsResults",
    "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankings",
    "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsBest",
    "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsCurrent",
    "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsParameters",
    "GetCalendarCompetitionResults",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResults",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResults",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsCompetitor",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsDetails",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartList",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartListCompetitor",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitor",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitorTeamMembers",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents",
    "GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters",
    "GetCalendarEvents",
    "GetCalendarEventsGetCalendarEvents",
    "GetCalendarEventsGetCalendarEventsOptions",
    "GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups",
    "GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups",
    "GetCalendarEventsGetCalendarEventsOptionsDisciplines",
    "GetCalendarEventsGetCalendarEventsOptionsPermitLevels",
    "GetCalendarEventsGetCalendarEventsOptionsRankingCategories",
    "GetCalendarEventsGetCalendarEventsOptionsRegions",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsArea",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsCountry",
    "GetCalendarEventsGetCalendarEventsOptionsRegionsWorld",
    "GetCalendarEventsGetCalendarEventsOptionsSeasons",
    "GetCalendarEventsGetCalendarEventsParameters",
    "GetCalendarEventsGetCalendarEventsResults",
    "GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod",
    "GetCampaign",
    "GetCampaignGetCampaign",
    "GetCampaigns",
    "GetCampaignsGetCampaigns",
    "GetCarousel",
    "GetCarouselGetCarousel",
    "GetCarouselGetCarouselCarouselItems",
    "GetCarouselGetCarouselCarouselItemsPrimaryMedia",
    "GetCarouselGetCarouselMedia",
    "GetChampionshipHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlightsDays",
    "GetChampionshipHighlightsGetChampionshipHighlightsRounds",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecords",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitorTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsChampionshipRecordsCompetitorTeamMembersTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHead",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadCompetitorPrimaryMedia",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponents",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsOpponent",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsOpponentPrimaryMedia",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHeadToHeadOpponentsResults",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlights",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitors",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitorsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsHighlightsCompetitorsCompetitorTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalists",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitorTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsPastMedalistsCompetitorTeamMembersTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecords",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitor",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitorTeamMembers",
    "GetChampionshipHighlightsGetChampionshipHighlightsRoundsWorldRecordsCompetitorTeamMembersTeamMembers",
    "GetChampionshipQualifications",
    "GetChampionshipQualificationsGetChampionshipQualifications",
    "GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards",
    "GetChampionshipQualificationsGetChampionshipQualificationsCountries",
    "GetChampionshipQualificationsGetChampionshipQualificationsEvents",
    "GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes",
    "GetChampionshipQualificationsGetChampionshipQualificationsQualifications",
    "GetCombinedPoints",
    "GetCombinedPointsGetCombinedPoints",
    "GetCombinedPointsGetCombinedPointsAllDisciplines",
    "GetCombinedPointsGetCombinedPointsCompetitors",
    "GetCombinedPointsGetCombinedPointsCompetitorsDisciplines",
    "GetCompetitionOrganiserInfo",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersons",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoPrizeMoney",
    "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits",
    "GetCompetitor",
    "GetCompetitorAAId",
    "GetCompetitorGetCompetitor",
    "GetCompetitorsLegacyPrimaryMedia",
    "GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia",
    "GetContactPreferences",
    "GetContactPreferencesGetContactPreferences",
    "GetContactPreferencesGetContactPreferencesData",
    "GetCountries",
    "GetCountriesGetCountries",
    "GetDiscipline",
    "GetDisciplineGetDiscipline",
    "GetDraftedArticle",
    "GetDraftedArticleGetDraftedArticle",
    "GetDraftedArticleGetDraftedArticleContentModules",
    "GetDraftedArticleGetDraftedArticleContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleEvent",
    "GetDraftedArticleGetDraftedArticleEventCircuits",
    "GetDraftedArticleGetDraftedArticleEventPage",
    "GetDraftedArticleGetDraftedArticleEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesBannersPage",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageCampaign",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageContentModules",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageEvent",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisitePageMinisite",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesSectionsLinks",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleEventPageContentModulesVideosThumbnailImage",
    "GetDraftedArticleGetDraftedArticleEventPageEvent",
    "GetDraftedArticleGetDraftedArticleEventPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleEventPageEventPage",
    "GetDraftedArticleGetDraftedArticleEventPageEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleEventPageEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleEventPageEventPageEvent",
    "GetDraftedArticleGetDraftedArticleEventPageEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleEventPageMinisiteSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesEventPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedEventsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStats",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsRecords",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResults",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsResultsDetails",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedEventsPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesBannersPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsLastEventPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsNextEventPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesBannersPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSectionsLinks",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStats",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsPreviousMedalists",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsRecords",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResults",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResults",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsCompetitor",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsCompetitorTeamMembers",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsResultsDetails",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsStartList",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsResultsStartListCompetitor",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsSeasonBest",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsTimetable",
    "GetDraftedArticleGetDraftedArticleRelatedDisciplineStatsTimetableDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesBannersPage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisitePageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSectionsLinks",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageContentModulesVideosThumbnailImage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedEventsPageMinisiteSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesBannersPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesLocationsLocation",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedEventsPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinksFile",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSectionsLinksPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageCampaign",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModules",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesBanners",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesFeatureLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesLifestyleLinks",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesLocations",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesMinisitePage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedArticles",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedCompetitors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedDiscipline",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedEvents",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedMedia",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedVideo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesRelatedVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesSections",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesSlides",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageContentModulesVideos",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEvent",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEventCircuits",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageEventPage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesEventPageMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisite",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteFeatureImage",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsors",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetDraftedArticleGetDraftedArticleRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetEvent",
    "GetEventBrokenRecords",
    "GetEventBrokenRecordsGetEventBrokenRecords",
    "GetEventBrokenRecordsGetEventBrokenRecordsDiscipline",
    "GetEventCircuitStandings",
    "GetEventCircuitStandingsGetEventCircuitStandings",
    "GetEventCircuitStandingsGetEventCircuitStandingsParameters",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandings",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries",
    "GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults",
    "GetEventGetEvent",
    "GetEventGetEventCircuits",
    "GetEventGetEventRelatedMedia",
    "GetEventLeadingStandings",
    "GetEventLeadingStandingsGetEventLeadingStandings",
    "GetEventLeadingStandingsGetEventLeadingStandingsDiscipline",
    "GetEventPhaseByDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings",
    "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers",
    "GetEventPhaseResultDetail",
    "GetEventPhaseResultDetailGetEventPhaseResultDetail",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailDiscipline",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailResult",
    "GetEventPhaseResultDetailGetEventPhaseResultDetailResultDiscipline",
    "GetEventPhaseResults",
    "GetEventPhaseResultsGetEventPhaseResults",
    "GetEventPhaseResultsGetEventPhaseResultsDiscipline",
    "GetEventPhaseResultsGetEventPhaseResultsResult",
    "GetEventPhaseResultsGetEventPhaseResultsResultDiscipline",
    "GetEventPhases",
    "GetEventPhasesGetEventPhases",
    "GetEventPhasesGetEventPhasesDiscipline",
    "GetEventTeamStandingDetails",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetails",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor",
    "GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline",
    "GetEventTeamStandings",
    "GetEventTeamStandingsGetEventTeamStandings",
    "GetEventTimetable",
    "GetEventTimetableGetEventTimetable",
    "GetEventTimetableGetEventTimetableDiscipline",
    "GetEventTimetableWithContent",
    "GetEventTimetableWithContentGetEventTimetableWithContent",
    "GetEventTimetableWithContentGetEventTimetableWithContentDiscipline",
    "GetEventTimetableWithContentGetEventTimetableWithContentDocuments",
    "GetEventTimetableWithContentGetEventTimetableWithContentSummary",
    "GetEventTimetableWithContentGetEventTimetableWithContentSummaryTeamMembers",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnits",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsResults",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsResultsTeamMembers",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsSeries",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsSeriesAttempts",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsSplits",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsStartlist",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsStartlistTeamMembers",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsTeamStandings",
    "GetEventTimetableWithContentGetEventTimetableWithContentUnitsTeamStandingsTeamMembers",
    "GetEvents",
    "GetEventsGetEvents",
    "GetEventsGetEventsCircuits",
    "GetEventsGetEventsPage",
    "GetEventsGetEventsPageCampaign",
    "GetEventsGetEventsPageContentModules",
    "GetEventsGetEventsPageContentModulesBanners",
    "GetEventsGetEventsPageContentModulesBannersPage",
    "GetEventsGetEventsPageContentModulesBannersPageCampaign",
    "GetEventsGetEventsPageContentModulesBannersPageContentModules",
    "GetEventsGetEventsPageContentModulesBannersPageEvent",
    "GetEventsGetEventsPageContentModulesBannersPageMinisite",
    "GetEventsGetEventsPageContentModulesFeatureLinks",
    "GetEventsGetEventsPageContentModulesLifestyleLinks",
    "GetEventsGetEventsPageContentModulesLocations",
    "GetEventsGetEventsPageContentModulesLocationsLocation",
    "GetEventsGetEventsPageContentModulesMinisite",
    "GetEventsGetEventsPageContentModulesMinisiteDefaultSponsors",
    "GetEventsGetEventsPageContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetEventsGetEventsPageContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetEventsGetEventsPageContentModulesMinisiteFeatureImage",
    "GetEventsGetEventsPageContentModulesMinisiteLogo",
    "GetEventsGetEventsPageContentModulesMinisitePage",
    "GetEventsGetEventsPageContentModulesMinisitePageCampaign",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModules",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesBanners",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesFeatureLinks",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesLocations",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesMinisite",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesMinisitePage",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedArticles",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedEvents",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedMedia",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedVideo",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesRelatedVideos",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesSections",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesSlides",
    "GetEventsGetEventsPageContentModulesMinisitePageContentModulesVideos",
    "GetEventsGetEventsPageContentModulesMinisitePageEvent",
    "GetEventsGetEventsPageContentModulesMinisitePageEventCircuits",
    "GetEventsGetEventsPageContentModulesMinisitePageEventPage",
    "GetEventsGetEventsPageContentModulesMinisitePageMinisite",
    "GetEventsGetEventsPageContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetEventsGetEventsPageContentModulesMinisitePageMinisiteFeatureImage",
    "GetEventsGetEventsPageContentModulesMinisitePageMinisiteLogo",
    "GetEventsGetEventsPageContentModulesMinisitePageMinisiteSponsors",
    "GetEventsGetEventsPageContentModulesMinisiteSponsors",
    "GetEventsGetEventsPageContentModulesMinisiteSponsorsDarkBgLogo",
    "GetEventsGetEventsPageContentModulesMinisiteSponsorsLightBgLogo",
    "GetEventsGetEventsPageContentModulesRelatedArticles",
    "GetEventsGetEventsPageContentModulesRelatedArticlesContentModules",
    "GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesLocations",
    "GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetEventsGetEventsPageContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetEventsGetEventsPageContentModulesRelatedArticlesEvent",
    "GetEventsGetEventsPageContentModulesRelatedArticlesEventCircuits",
    "GetEventsGetEventsPageContentModulesRelatedArticlesEventPage",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticles",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEvents",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedEventsPage",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedLinks",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMedia",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetEventsGetEventsPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetEventsGetEventsPageContentModulesRelatedCompetitors",
    "GetEventsGetEventsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetEventsGetEventsPageContentModulesRelatedDiscipline",
    "GetEventsGetEventsPageContentModulesRelatedEvents",
    "GetEventsGetEventsPageContentModulesRelatedEventsCircuits",
    "GetEventsGetEventsPageContentModulesRelatedEventsPage",
    "GetEventsGetEventsPageContentModulesRelatedEventsPageCampaign",
    "GetEventsGetEventsPageContentModulesRelatedEventsPageContentModules",
    "GetEventsGetEventsPageContentModulesRelatedEventsPageEvent",
    "GetEventsGetEventsPageContentModulesRelatedEventsPageMinisite",
    "GetEventsGetEventsPageContentModulesRelatedMedia",
    "GetEventsGetEventsPageContentModulesRelatedVideo",
    "GetEventsGetEventsPageContentModulesRelatedVideos",
    "GetEventsGetEventsPageContentModulesSections",
    "GetEventsGetEventsPageContentModulesSectionsLinks",
    "GetEventsGetEventsPageContentModulesSectionsLinksFile",
    "GetEventsGetEventsPageContentModulesSectionsLinksPage",
    "GetEventsGetEventsPageContentModulesSlides",
    "GetEventsGetEventsPageContentModulesVideos",
    "GetEventsGetEventsPageContentModulesVideosThumbnailImage",
    "GetEventsGetEventsPageEvent",
    "GetEventsGetEventsPageEventCircuits",
    "GetEventsGetEventsPageEventPage",
    "GetEventsGetEventsPageEventPageCampaign",
    "GetEventsGetEventsPageEventPageContentModules",
    "GetEventsGetEventsPageEventPageContentModulesBanners",
    "GetEventsGetEventsPageEventPageContentModulesFeatureLinks",
    "GetEventsGetEventsPageEventPageContentModulesLifestyleLinks",
    "GetEventsGetEventsPageEventPageContentModulesLocations",
    "GetEventsGetEventsPageEventPageContentModulesMinisite",
    "GetEventsGetEventsPageEventPageContentModulesMinisitePage",
    "GetEventsGetEventsPageEventPageContentModulesRelatedArticles",
    "GetEventsGetEventsPageEventPageContentModulesRelatedCompetitors",
    "GetEventsGetEventsPageEventPageContentModulesRelatedDiscipline",
    "GetEventsGetEventsPageEventPageContentModulesRelatedEvents",
    "GetEventsGetEventsPageEventPageContentModulesRelatedMedia",
    "GetEventsGetEventsPageEventPageContentModulesRelatedVideo",
    "GetEventsGetEventsPageEventPageContentModulesRelatedVideos",
    "GetEventsGetEventsPageEventPageContentModulesSections",
    "GetEventsGetEventsPageEventPageContentModulesSlides",
    "GetEventsGetEventsPageEventPageContentModulesVideos",
    "GetEventsGetEventsPageEventPageEvent",
    "GetEventsGetEventsPageEventPageEventCircuits",
    "GetEventsGetEventsPageEventPageEventPage",
    "GetEventsGetEventsPageEventPageMinisite",
    "GetEventsGetEventsPageEventPageMinisiteDefaultSponsors",
    "GetEventsGetEventsPageEventPageMinisiteFeatureImage",
    "GetEventsGetEventsPageEventPageMinisiteLogo",
    "GetEventsGetEventsPageEventPageMinisiteSponsors",
    "GetEventsGetEventsPageMinisite",
    "GetEventsGetEventsPageMinisiteDefaultSponsors",
    "GetEventsGetEventsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetEventsGetEventsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetEventsGetEventsPageMinisiteFeatureImage",
    "GetEventsGetEventsPageMinisiteLogo",
    "GetEventsGetEventsPageMinisiteSponsors",
    "GetEventsGetEventsPageMinisiteSponsorsDarkBgLogo",
    "GetEventsGetEventsPageMinisiteSponsorsLightBgLogo",
    "GetFilterTypes",
    "GetFilterTypesGetFilterTypes",
    "GetFilterTypesGetFilterTypesFilters",
    "GetFilterTypesGetFilterTypesFiltersType",
    "GetFilterTypesGetFilterTypesFiltersTypeFilters",
    "GetFilterTypesGetFilterTypesFiltersTypeFiltersType",
    "GetFilterTypesGetFilterTypesFiltersTypeFiltersTypeFilters",
    "GetFlashInterviews",
    "GetFlashInterviewsGetFlashInterviews",
    "GetFlashInterviewsGetFlashInterviewsInterviews",
    "GetHeroAthletesCarousel",
    "GetHeroAthletesCarouselGetHeroAthletesCarousel",
    "GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia",
    "GetLatestQualifiedCompetitors",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor",
    "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers",
    "GetLatestRecords",
    "GetLatestRecordsGetLatestRecords",
    "GetLatestRecordsGetLatestRecordsRecords",
    "GetLatestRecordsGetLatestRecordsRecordsCompetitor",
    "GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers",
    "GetLeadingAthletes",
    "GetLeadingAthletesGetLeadingAthletes",
    "GetLeadingAthletesGetLeadingAthletesEventResults",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResults",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitor",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResultsCompetitorTeamMembers",
    "GetLeadingAthletesGetLeadingAthletesEventResultsResultsPrimaryMedia",
    "GetLegacyPage",
    "GetLegacyPageGetLegacyPage",
    "GetLegacyPageGetLegacyPageContent",
    "GetLegacyPageGetLegacyPageContentLegacyDocument",
    "GetLegacyPageGetLegacyPageContentLegacyDocumentFiles",
    "GetLegacyPageGetLegacyPageContentRelatedMedia",
    "GetLegacyPageGetLegacyPageTemplate",
    "GetLiveBlogPosts",
    "GetLiveBlogPostsGetLiveBlogPosts",
    "GetLiveCombinedSummaryDetails",
    "GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails",
    "GetLivePhaseSummary",
    "GetLivePhaseSummaryGetLivePhaseSummary",
    "GetLiveResult",
    "GetLiveResultGetLiveResult",
    "GetLiveResultGetLiveResultTeamMembers",
    "GetMedal",
    "GetMedalDetails",
    "GetMedalDetailsGetMedalDetails",
    "GetMedalGetMedal",
    "GetMedals",
    "GetMedalsGetMedals",
    "GetMedalsGetMedalsCountry",
    "GetMedia",
    "GetMediaGetMedia",
    "GetMedias",
    "GetMediasGetMedias",
    "GetMetaData",
    "GetMetaDataGetMetaData",
    "GetMetaDataGetMetaDataCountryCodes",
    "GetMetaDataGetMetaDataDisciplineCodes",
    "GetMinisiteCalendarEvents",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEvents",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults",
    "GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod",
    "GetNewArticle",
    "GetNewArticleGetNewArticle",
    "GetNewArticleGetNewArticleContentModules",
    "GetNewArticleGetNewArticleContentModulesLocations",
    "GetNewArticleGetNewArticleContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleEvent",
    "GetNewArticleGetNewArticleEventCircuits",
    "GetNewArticleGetNewArticleEventPage",
    "GetNewArticleGetNewArticleEventPageCampaign",
    "GetNewArticleGetNewArticleEventPageContentModules",
    "GetNewArticleGetNewArticleEventPageContentModulesBanners",
    "GetNewArticleGetNewArticleEventPageContentModulesBannersPage",
    "GetNewArticleGetNewArticleEventPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleEventPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleEventPageContentModulesLocations",
    "GetNewArticleGetNewArticleEventPageContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisite",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisiteLogo",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisitePageCampaign",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisitePageContentModules",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisitePageEvent",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisitePageMinisite",
    "GetNewArticleGetNewArticleEventPageContentModulesMinisiteSponsors",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedEventsPage",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleEventPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleEventPageContentModulesSections",
    "GetNewArticleGetNewArticleEventPageContentModulesSectionsLinks",
    "GetNewArticleGetNewArticleEventPageContentModulesSlides",
    "GetNewArticleGetNewArticleEventPageContentModulesVideos",
    "GetNewArticleGetNewArticleEventPageContentModulesVideosThumbnailImage",
    "GetNewArticleGetNewArticleEventPageEvent",
    "GetNewArticleGetNewArticleEventPageEventCircuits",
    "GetNewArticleGetNewArticleEventPageEventPage",
    "GetNewArticleGetNewArticleEventPageEventPageCampaign",
    "GetNewArticleGetNewArticleEventPageEventPageContentModules",
    "GetNewArticleGetNewArticleEventPageEventPageEvent",
    "GetNewArticleGetNewArticleEventPageEventPageMinisite",
    "GetNewArticleGetNewArticleEventPageMinisite",
    "GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleEventPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleEventPageMinisiteLogo",
    "GetNewArticleGetNewArticleEventPageMinisiteSponsors",
    "GetNewArticleGetNewArticleEventPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleEventPageMinisiteSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesEventPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedEventsPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStats",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsResultsDetails",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedEventsPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesBannersPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageEvent",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsLastEventPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsNextEventPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesBannersPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisitePageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSectionsLinks",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageContentModulesVideosThumbnailImage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventPage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageEvent",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisite",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedCompetitionsPageMinisiteSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedDisciplineStats",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsDiscipline",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsRecords",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResults",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResults",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsCompetitor",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsCompetitorTeamMembers",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsResultsDetails",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsStartList",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsResultsStartListCompetitor",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsSeasonBest",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsTimetable",
    "GetNewArticleGetNewArticleRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticleGetNewArticleRelatedEvents",
    "GetNewArticleGetNewArticleRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedEventsPageCampaign",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModules",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesBannersPage",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageCampaign",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageContentModules",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageEvent",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisitePageMinisite",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesSectionsLinks",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedEventsPageContentModulesVideosThumbnailImage",
    "GetNewArticleGetNewArticleRelatedEventsPageEvent",
    "GetNewArticleGetNewArticleRelatedEventsPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedEventsPageEventPage",
    "GetNewArticleGetNewArticleRelatedEventsPageEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedEventsPageEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedEventsPageEventPageEvent",
    "GetNewArticleGetNewArticleRelatedEventsPageEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisite",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedEventsPageMinisiteSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedLinks",
    "GetNewArticleGetNewArticleRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesBannersPageMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesLocationsLocation",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEventCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageEventPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesEventPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedEventsPageMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSections",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinksFile",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSectionsLinksPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageCampaign",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModules",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesBanners",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesFeatureLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesLifestyleLinks",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesLocations",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesMinisitePage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedArticles",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedCompetitors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedDiscipline",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedEvents",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedMedia",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedVideo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesRelatedVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesSections",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesSlides",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageContentModulesVideos",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEvent",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEventCircuits",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageEventPage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesEventPageMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisite",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetNewArticleGetNewArticleRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetNewArticles",
    "GetNewArticlesGetNewArticles",
    "GetNewArticlesGetNewArticlesContentModules",
    "GetNewArticlesGetNewArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesEvent",
    "GetNewArticlesGetNewArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesEventPage",
    "GetNewArticlesGetNewArticlesEventPageCampaign",
    "GetNewArticlesGetNewArticlesEventPageContentModules",
    "GetNewArticlesGetNewArticlesEventPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesEventPageContentModulesBannersPage",
    "GetNewArticlesGetNewArticlesEventPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesEventPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesEventPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesEventPageContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteLogo",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageCampaign",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageContentModules",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageEvent",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisitePageMinisite",
    "GetNewArticlesGetNewArticlesEventPageContentModulesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesEventPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesEventPageContentModulesSections",
    "GetNewArticlesGetNewArticlesEventPageContentModulesSectionsLinks",
    "GetNewArticlesGetNewArticlesEventPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesEventPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesEventPageContentModulesVideosThumbnailImage",
    "GetNewArticlesGetNewArticlesEventPageEvent",
    "GetNewArticlesGetNewArticlesEventPageEventCircuits",
    "GetNewArticlesGetNewArticlesEventPageEventPage",
    "GetNewArticlesGetNewArticlesEventPageEventPageCampaign",
    "GetNewArticlesGetNewArticlesEventPageEventPageContentModules",
    "GetNewArticlesGetNewArticlesEventPageEventPageEvent",
    "GetNewArticlesGetNewArticlesEventPageEventPageMinisite",
    "GetNewArticlesGetNewArticlesEventPageMinisite",
    "GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesEventPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesEventPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesEventPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesEventPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesEventPageMinisiteSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesEventPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedEventsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResultsCompetitor",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsResultsDetails",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsResultsStartListCompetitor",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedEventsPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesBannersPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSectionsLinks",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsLastEventPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsNextEventPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesBannersPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisitePageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSectionsLinks",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageContentModulesVideosThumbnailImage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitionsPageMinisiteSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStats",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsRecords",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResults",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResults",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsCompetitor",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsCompetitorTeamMembers",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsResultsDetails",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsStartList",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsResultsStartListCompetitor",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticlesGetNewArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetNewArticlesGetNewArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesBannersPage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageCampaign",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageContentModules",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageEvent",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisitePageMinisite",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSectionsLinks",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedEventsPageContentModulesVideosThumbnailImage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedEventsPageEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedEventsPageMinisiteSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesBannersPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesLocationsLocation",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageEventPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisitePageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesMinisiteSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesEventPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitions",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePages",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedCompetitorsPrimaryMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedEventsPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinksFile",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSectionsLinksPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesContentModulesVideosThumbnailImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageCampaign",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModules",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesBanners",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesFeatureLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesLifestyleLinks",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesLocations",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesMinisitePage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedArticles",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedCompetitors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedDiscipline",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedEvents",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedMedia",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedVideo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesRelatedVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesSections",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesSlides",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageContentModulesVideos",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEvent",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEventCircuits",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageEventPage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesEventPageMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisite",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteDefaultSponsorsLightBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsorsDarkBgLogo",
    "GetNewArticlesGetNewArticlesRelatedMinisitePagesMinisiteSponsorsLightBgLogo",
    "GetNewMedias",
    "GetNewMediasGetNewMedias",
    "GetNewsTicker",
    "GetNewsTickerGetNewsTicker",
    "GetOnThisDay",
    "GetOnThisDayGetOnThisDay",
    "GetOnThisDayGetOnThisDayResults",
    "GetPage",
    "GetPageGetPage",
    "GetPageGetPageCampaign",
    "GetPageGetPageContentModules",
    "GetPageGetPageContentModulesBanners",
    "GetPageGetPageContentModulesBannersPage",
    "GetPageGetPageContentModulesBannersPageCampaign",
    "GetPageGetPageContentModulesBannersPageContentModules",
    "GetPageGetPageContentModulesBannersPageContentModulesBanners",
    "GetPageGetPageContentModulesBannersPageContentModulesFeatureLinks",
    "GetPageGetPageContentModulesBannersPageContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesBannersPageContentModulesLocations",
    "GetPageGetPageContentModulesBannersPageContentModulesMinisite",
    "GetPageGetPageContentModulesBannersPageContentModulesMinisitePage",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedArticles",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedEvents",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedMedia",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedVideo",
    "GetPageGetPageContentModulesBannersPageContentModulesRelatedVideos",
    "GetPageGetPageContentModulesBannersPageContentModulesSections",
    "GetPageGetPageContentModulesBannersPageContentModulesSlides",
    "GetPageGetPageContentModulesBannersPageContentModulesVideos",
    "GetPageGetPageContentModulesBannersPageEvent",
    "GetPageGetPageContentModulesBannersPageEventCircuits",
    "GetPageGetPageContentModulesBannersPageEventPage",
    "GetPageGetPageContentModulesBannersPageMinisite",
    "GetPageGetPageContentModulesBannersPageMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesBannersPageMinisiteFeatureImage",
    "GetPageGetPageContentModulesBannersPageMinisiteLogo",
    "GetPageGetPageContentModulesBannersPageMinisiteSponsors",
    "GetPageGetPageContentModulesFeatureLinks",
    "GetPageGetPageContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesLocations",
    "GetPageGetPageContentModulesLocationsLocation",
    "GetPageGetPageContentModulesMinisite",
    "GetPageGetPageContentModulesMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetPageGetPageContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetPageGetPageContentModulesMinisiteFeatureImage",
    "GetPageGetPageContentModulesMinisiteLogo",
    "GetPageGetPageContentModulesMinisitePage",
    "GetPageGetPageContentModulesMinisitePageCampaign",
    "GetPageGetPageContentModulesMinisitePageContentModules",
    "GetPageGetPageContentModulesMinisitePageContentModulesBanners",
    "GetPageGetPageContentModulesMinisitePageContentModulesBannersPage",
    "GetPageGetPageContentModulesMinisitePageContentModulesFeatureLinks",
    "GetPageGetPageContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesMinisitePageContentModulesLocations",
    "GetPageGetPageContentModulesMinisitePageContentModulesLocationsLocation",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisite",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisiteFeatureImage",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisiteLogo",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisitePage",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageCampaign",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageContentModules",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageEvent",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisitePageMinisite",
    "GetPageGetPageContentModulesMinisitePageContentModulesMinisiteSponsors",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticles",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesContentModules",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesEvent",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedArticles",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedEvents",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedLinks",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedMedia",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedEvents",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedEventsCircuits",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedEventsPage",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedMedia",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedVideo",
    "GetPageGetPageContentModulesMinisitePageContentModulesRelatedVideos",
    "GetPageGetPageContentModulesMinisitePageContentModulesSections",
    "GetPageGetPageContentModulesMinisitePageContentModulesSectionsLinks",
    "GetPageGetPageContentModulesMinisitePageContentModulesSlides",
    "GetPageGetPageContentModulesMinisitePageContentModulesVideos",
    "GetPageGetPageContentModulesMinisitePageContentModulesVideosThumbnailImage",
    "GetPageGetPageContentModulesMinisitePageEvent",
    "GetPageGetPageContentModulesMinisitePageEventCircuits",
    "GetPageGetPageContentModulesMinisitePageEventPage",
    "GetPageGetPageContentModulesMinisitePageEventPageCampaign",
    "GetPageGetPageContentModulesMinisitePageEventPageContentModules",
    "GetPageGetPageContentModulesMinisitePageEventPageEvent",
    "GetPageGetPageContentModulesMinisitePageEventPageMinisite",
    "GetPageGetPageContentModulesMinisitePageMinisite",
    "GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsorsDarkBgLogo",
    "GetPageGetPageContentModulesMinisitePageMinisiteDefaultSponsorsLightBgLogo",
    "GetPageGetPageContentModulesMinisitePageMinisiteFeatureImage",
    "GetPageGetPageContentModulesMinisitePageMinisiteLogo",
    "GetPageGetPageContentModulesMinisitePageMinisiteSponsors",
    "GetPageGetPageContentModulesMinisitePageMinisiteSponsorsDarkBgLogo",
    "GetPageGetPageContentModulesMinisitePageMinisiteSponsorsLightBgLogo",
    "GetPageGetPageContentModulesMinisiteSponsors",
    "GetPageGetPageContentModulesMinisiteSponsorsDarkBgLogo",
    "GetPageGetPageContentModulesMinisiteSponsorsLightBgLogo",
    "GetPageGetPageContentModulesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesContentModulesLocations",
    "GetPageGetPageContentModulesRelatedArticlesContentModulesLocationsLocation",
    "GetPageGetPageContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetPageGetPageContentModulesRelatedArticlesEvent",
    "GetPageGetPageContentModulesRelatedArticlesEventCircuits",
    "GetPageGetPageContentModulesRelatedArticlesEventPage",
    "GetPageGetPageContentModulesRelatedArticlesEventPageCampaign",
    "GetPageGetPageContentModulesRelatedArticlesEventPageContentModules",
    "GetPageGetPageContentModulesRelatedArticlesEventPageEvent",
    "GetPageGetPageContentModulesRelatedArticlesEventPageMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesLocations",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesContentModulesRelatedVideos",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEventCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesEventPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitionsPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStats",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsResults",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEventsCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedEventsPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEventCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsLastEventPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEventCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsNextEventPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageCampaign",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitionsPageMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResultsResults",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsResultsStartList",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetPageGetPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetableDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEvents",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageCampaign",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedEventsPageMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesBanners",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesFeatureLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesLocations",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesMinisitePage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedArticles",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedEvents",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedMedia",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesRelatedVideos",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesSections",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesSlides",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesContentModulesVideos",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEventCircuits",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesEventPage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteFeatureImage",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteLogo",
    "GetPageGetPageContentModulesRelatedArticlesRelatedMinisitePagesMinisiteSponsors",
    "GetPageGetPageContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedEvents",
    "GetPageGetPageContentModulesRelatedEventsCircuits",
    "GetPageGetPageContentModulesRelatedEventsPage",
    "GetPageGetPageContentModulesRelatedEventsPageCampaign",
    "GetPageGetPageContentModulesRelatedEventsPageContentModules",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesBanners",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesFeatureLinks",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesLifestyleLinks",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesLocations",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesMinisite",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesMinisitePage",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedArticles",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedCompetitors",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedDiscipline",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedEvents",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedMedia",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesRelatedVideos",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesSections",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesSlides",
    "GetPageGetPageContentModulesRelatedEventsPageContentModulesVideos",
    "GetPageGetPageContentModulesRelatedEventsPageEvent",
    "GetPageGetPageContentModulesRelatedEventsPageEventCircuits",
    "GetPageGetPageContentModulesRelatedEventsPageEventPage",
    "GetPageGetPageContentModulesRelatedEventsPageMinisite",
    "GetPageGetPageContentModulesRelatedEventsPageMinisiteDefaultSponsors",
    "GetPageGetPageContentModulesRelatedEventsPageMinisiteFeatureImage",
    "GetPageGetPageContentModulesRelatedEventsPageMinisiteLogo",
    "GetPageGetPageContentModulesRelatedEventsPageMinisiteSponsors",
    "GetPageGetPageContentModulesRelatedMedia",
    "GetPageGetPageContentModulesRelatedVideo",
    "GetPageGetPageContentModulesRelatedVideos",
    "GetPageGetPageContentModulesSections",
    "GetPageGetPageContentModulesSectionsLinks",
    "GetPageGetPageContentModulesSectionsLinksFile",
    "GetPageGetPageContentModulesSectionsLinksPage",
    "GetPageGetPageContentModulesSectionsLinksPageCampaign",
    "GetPageGetPageContentModulesSectionsLinksPageContentModules",
    "GetPageGetPageContentModulesSectionsLinksPageEvent",
    "GetPageGetPageContentModulesSectionsLinksPageMinisite",
    "GetPageGetPageContentModulesSlides",
    "GetPageGetPageContentModulesVideos",
    "GetPageGetPageContentModulesVideosThumbnailImage",
    "GetPageGetPageEvent",
    "GetPageGetPageEventCircuits",
    "GetPageGetPageEventPage",
    "GetPageGetPageEventPageCampaign",
    "GetPageGetPageEventPageContentModules",
    "GetPageGetPageEventPageContentModulesBanners",
    "GetPageGetPageEventPageContentModulesBannersPage",
    "GetPageGetPageEventPageContentModulesFeatureLinks",
    "GetPageGetPageEventPageContentModulesLifestyleLinks",
    "GetPageGetPageEventPageContentModulesLocations",
    "GetPageGetPageEventPageContentModulesLocationsLocation",
    "GetPageGetPageEventPageContentModulesMinisite",
    "GetPageGetPageEventPageContentModulesMinisiteDefaultSponsors",
    "GetPageGetPageEventPageContentModulesMinisiteFeatureImage",
    "GetPageGetPageEventPageContentModulesMinisiteLogo",
    "GetPageGetPageEventPageContentModulesMinisitePage",
    "GetPageGetPageEventPageContentModulesMinisitePageCampaign",
    "GetPageGetPageEventPageContentModulesMinisitePageContentModules",
    "GetPageGetPageEventPageContentModulesMinisitePageEvent",
    "GetPageGetPageEventPageContentModulesMinisitePageMinisite",
    "GetPageGetPageEventPageContentModulesMinisiteSponsors",
    "GetPageGetPageEventPageContentModulesRelatedArticles",
    "GetPageGetPageEventPageContentModulesRelatedArticlesContentModules",
    "GetPageGetPageEventPageContentModulesRelatedArticlesEvent",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetPageGetPageEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetPageGetPageEventPageContentModulesRelatedCompetitors",
    "GetPageGetPageEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetPageGetPageEventPageContentModulesRelatedDiscipline",
    "GetPageGetPageEventPageContentModulesRelatedEvents",
    "GetPageGetPageEventPageContentModulesRelatedEventsCircuits",
    "GetPageGetPageEventPageContentModulesRelatedEventsPage",
    "GetPageGetPageEventPageContentModulesRelatedMedia",
    "GetPageGetPageEventPageContentModulesRelatedVideo",
    "GetPageGetPageEventPageContentModulesRelatedVideos",
    "GetPageGetPageEventPageContentModulesSections",
    "GetPageGetPageEventPageContentModulesSectionsLinks",
    "GetPageGetPageEventPageContentModulesSlides",
    "GetPageGetPageEventPageContentModulesVideos",
    "GetPageGetPageEventPageContentModulesVideosThumbnailImage",
    "GetPageGetPageEventPageEvent",
    "GetPageGetPageEventPageEventCircuits",
    "GetPageGetPageEventPageEventPage",
    "GetPageGetPageEventPageEventPageCampaign",
    "GetPageGetPageEventPageEventPageContentModules",
    "GetPageGetPageEventPageEventPageEvent",
    "GetPageGetPageEventPageEventPageMinisite",
    "GetPageGetPageEventPageMinisite",
    "GetPageGetPageEventPageMinisiteDefaultSponsors",
    "GetPageGetPageEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetPageGetPageEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetPageGetPageEventPageMinisiteFeatureImage",
    "GetPageGetPageEventPageMinisiteLogo",
    "GetPageGetPageEventPageMinisiteSponsors",
    "GetPageGetPageEventPageMinisiteSponsorsDarkBgLogo",
    "GetPageGetPageEventPageMinisiteSponsorsLightBgLogo",
    "GetPageGetPageMinisite",
    "GetPageGetPageMinisiteDefaultSponsors",
    "GetPageGetPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetPageGetPageMinisiteDefaultSponsorsLightBgLogo",
    "GetPageGetPageMinisiteFeatureImage",
    "GetPageGetPageMinisiteLogo",
    "GetPageGetPageMinisiteSponsors",
    "GetPageGetPageMinisiteSponsorsDarkBgLogo",
    "GetPageGetPageMinisiteSponsorsLightBgLogo",
    "GetPhases",
    "GetPhasesGetPhases",
    "GetPhasesGetPhasesUnits",
    "GetPlacingTable",
    "GetPlacingTableDetails",
    "GetPlacingTableDetailsGetPlacingTableDetails",
    "GetPlacingTableGetPlacingTable",
    "GetPreChampionshipHighlights",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlights",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembersTeamMembersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembersTeamMembersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembersTeamMembers",
    "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembersTeamMembersTeamMembers",
    "GetPredictorGameBanner",
    "GetPredictorGameBannerGetPredictorGameBanner",
    "GetPredictorGameNotification",
    "GetPredictorGameNotificationGetPredictorGameNotification",
    "GetRandomWorldRankingDiscipline",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery",
    "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings",
    "GetRankingGroups",
    "GetRankingGroupsGetRankingGroups",
    "GetRankingGroupsGetRankingGroupsEvents",
    "GetRankingScoreCalculation",
    "GetRankingScoreCalculationGetRankingScoreCalculation",
    "GetRankingScoreCalculationGetRankingScoreCalculationResults",
    "GetRecentResults",
    "GetRecentResultsGetRecentResults",
    "GetRecentResultsGetRecentResultsResults",
    "GetRecentResultsGetRecentResultsResultsEvent",
    "GetRecentResultsGetRecentResultsResultsEventCircuits",
    "GetRecentResultsGetRecentResultsResultsEventPage",
    "GetRecentResultsGetRecentResultsResultsEventPageCampaign",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModules",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesBanners",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesFeatureLinks",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesLifestyleLinks",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesLocations",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesMinisite",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesMinisitePage",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedArticles",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedCompetitors",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedDiscipline",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedEvents",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedMedia",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedVideo",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesRelatedVideos",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesSections",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesSlides",
    "GetRecentResultsGetRecentResultsResultsEventPageContentModulesVideos",
    "GetRecentResultsGetRecentResultsResultsEventPageEvent",
    "GetRecentResultsGetRecentResultsResultsEventPageEventCircuits",
    "GetRecentResultsGetRecentResultsResultsEventPageEventPage",
    "GetRecentResultsGetRecentResultsResultsEventPageMinisite",
    "GetRecentResultsGetRecentResultsResultsEventPageMinisiteDefaultSponsors",
    "GetRecentResultsGetRecentResultsResultsEventPageMinisiteFeatureImage",
    "GetRecentResultsGetRecentResultsResultsEventPageMinisiteLogo",
    "GetRecentResultsGetRecentResultsResultsEventPageMinisiteSponsors",
    "GetRecordsByCategory",
    "GetRecordsByCategoryGetRecordsByCategory",
    "GetRecordsByCategoryGetRecordsByCategoryCompetitor",
    "GetRecordsCategories",
    "GetRecordsCategoriesGetRecordsCategories",
    "GetRecordsCategoriesGetRecordsCategoriesItems",
    "GetRecordsCategoriesGetRecordsCategoriesItemsItems",
    "GetRecordsCategoriesGetRecordsCategoriesItemsItemsItems",
    "GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItems",
    "GetRecordsCategoriesGetRecordsCategoriesItemsItemsItemsItemsItems",
    "GetRecordsDetailByCategory",
    "GetRecordsDetailByCategoryGetRecordsDetailByCategory",
    "GetRecordsDetailByCategoryGetRecordsDetailByCategoryResults",
    "GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitor",
    "GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitorTeamMembers",
    "GetRecordsDetailByDiscipline",
    "GetRecordsDetailByDisciplineGetRecordsDetailByDiscipline",
    "GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItems",
    "GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitor",
    "GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitorTeamMembers",
    "GetRecordsDetailByProgression",
    "GetRecordsDetailByProgressionGetRecordsDetailByProgression",
    "GetRecordsDetailByProgressionGetRecordsDetailByProgressionDiscipline",
    "GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntries",
    "GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntriesCompetitor",
    "GetRecordsDetailByProgressionGetRecordsDetailByProgressionEntriesCompetitorTeamMembers",
    "GetRecordsDisciplineList",
    "GetRecordsDisciplineListGetRecordsDisciplineList",
    "GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypes",
    "GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypesDisciplines",
    "GetRecordsDisciplines",
    "GetRecordsDisciplinesGetRecordsDisciplines",
    "GetResultInfo",
    "GetResultInfoGetResultInfo",
    "GetSchedule",
    "GetScheduleGetSchedule",
    "GetScheduleGetScheduleDays",
    "GetScheduleGetScheduleDaysChannels",
    "GetSearchResults",
    "GetSearchResultsGetSearchResults",
    "GetSearchResultsGetSearchResultsItems",
    "GetSingleCompetitor",
    "GetSingleCompetitorAllTimePersonalTop10",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters",
    "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results",
    "GetSingleCompetitorGetSingleCompetitor",
    "GetSingleCompetitorGetSingleCompetitorAthleteRepresentative",
    "GetSingleCompetitorGetSingleCompetitorBasicData",
    "GetSingleCompetitorGetSingleCompetitorBasicDataPrimaryMedia",
    "GetSingleCompetitorGetSingleCompetitorHonours",
    "GetSingleCompetitorGetSingleCompetitorHonoursResults",
    "GetSingleCompetitorGetSingleCompetitorPersonalBests",
    "GetSingleCompetitorGetSingleCompetitorPersonalBestsResults",
    "GetSingleCompetitorGetSingleCompetitorPrimaryMedia",
    "GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBests",
    "GetSingleCompetitorGetSingleCompetitorProgressionOfSeasonsBestsResults",
    "GetSingleCompetitorGetSingleCompetitorResultsByDate",
    "GetSingleCompetitorGetSingleCompetitorResultsByDateParameters",
    "GetSingleCompetitorGetSingleCompetitorResultsByDateResultsByDate",
    "GetSingleCompetitorGetSingleCompetitorResultsByYear",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearParameters",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEvent",
    "GetSingleCompetitorGetSingleCompetitorResultsByYearResultsByEventResults",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBests",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBestsParameters",
    "GetSingleCompetitorGetSingleCompetitorSeasonsBestsResults",
    "GetSingleCompetitorGetSingleCompetitorWorldRankings",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsBest",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsCurrent",
    "GetSingleCompetitorGetSingleCompetitorWorldRankingsParameters",
    "GetSingleCompetitorHonourSummary",
    "GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary",
    "GetSingleCompetitorMajorChampionships",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults",
    "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults",
    "GetSingleCompetitorResultsByLimit",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters",
    "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults",
    "GetSingleCompetitorResultsDate",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDate",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateParameters",
    "GetSingleCompetitorResultsDateGetSingleCompetitorResultsDateResultsByDate",
    "GetSingleCompetitorResultsDiscipline",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent",
    "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults",
    "GetSingleCompetitorSeasonBests",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters",
    "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults",
    "GetSingleCompetitorWinningStreak",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks",
    "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults",
    "GetSocialCarousel",
    "GetSocialCarouselGetSocialCarousel",
    "GetSocialCarouselGetSocialCarouselPrimaryMedia",
    "GetSpikes",
    "GetSpikesGetSpikes",
    "GetSpikesGetSpikesPrimaryMedia",
    "GetSpikesGetSpikesRelatedTags",
    "GetTeamResults",
    "GetTeamResultsGetTeamResults",
    "GetTeamResultsGetTeamResultsTeamMembers",
    "GetTeamScoring",
    "GetTeamScoringGetTeamScoring",
    "GetTeamScoringGetTeamScoringAthlete",
    "GetTeamScoringGetTeamScoringAthleteDetail",
    "GetTopList",
    "GetTopListGetTopList",
    "GetTopListGetTopListPayload",
    "GetTopListsDisciplines",
    "GetTopListsDisciplinesGetTopListsDisciplines",
    "GetTopPanel",
    "GetTopPanelGetTopPanel",
    "GetTopRankings",
    "GetTopRankingsGetTopRankings",
    "GetTopRankingsGetTopRankingsRankings",
    "GetTopRankingsGetTopRankingsRankingsPrimaryMedia",
    "GetTrendingAthletes",
    "GetTrendingAthletesGetTrendingAthletes",
    "GetTrendingAthletesGetTrendingAthletesAthletesList",
    "GetTrendingAthletesGetTrendingAthletesAthletesListPrimaryMedia",
    "GetTrendingAthletesGetTrendingAthletesPrimaryMedia",
    "GetUpcomingCompetitions",
    "GetUpcomingCompetitionsGetUpcomingCompetitions",
    "GetUpcomingCompetitionsGetUpcomingCompetitionsCompetitions",
    "GetUser",
    "GetUserCountry",
    "GetUserCountryGetUserCountry",
    "GetUserGetUser",
    "GetUserGetUserSettings",
    "GetUserGetUserSettingsFollowedCountries",
    "GetUsersVotes",
    "GetUsersVotesGetUsersVotes",
    "GetVerification",
    "GetVerificationGetVerification",
    "GetVideoById",
    "GetVideoByIdGetVideoById",
    "GetVideoList",
    "GetVideoListGetVideoList",
    "GetVideoPlaylist",
    "GetVideoPlaylistGetVideoPlaylist",
    "GetVideosTotalNumber",
    "GetVideosTotalNumberGetVideosTotalNumber",
    "GetVocabulary",
    "GetVocabularyGetVocabulary",
    "GetVoteOptions",
    "GetVoteOptionsGetVoteOptions",
    "GetWawCompetition",
    "GetWawCompetitionEventsOrganizerDetails",
    "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails",
    "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails",
    "GetWawCompetitionGetWawCompetition",
    "GetWawCompetitionGetWawCompetitionLastEvent",
    "GetWawCompetitionGetWawCompetitionLastEventCircuits",
    "GetWawCompetitionGetWawCompetitionLastEventPage",
    "GetWawCompetitionGetWawCompetitionLastEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesBannersPage",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesLocationsLocation",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageCampaign",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageContentModules",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageEvent",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisitePageMinisite",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesContentModules",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesEvent",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEventsCircuits",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedEventsPage",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSectionsLinks",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionLastEventPageContentModulesVideosThumbnailImage",
    "GetWawCompetitionGetWawCompetitionLastEventPageEvent",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventCircuits",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventPage",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventPageEvent",
    "GetWawCompetitionGetWawCompetitionLastEventPageEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionLastEventPageMinisiteSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionNextEvent",
    "GetWawCompetitionGetWawCompetitionNextEventCircuits",
    "GetWawCompetitionGetWawCompetitionNextEventPage",
    "GetWawCompetitionGetWawCompetitionNextEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesBannersPage",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesLocationsLocation",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageCampaign",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageContentModules",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageEvent",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisitePageMinisite",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesContentModules",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesEvent",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEventsCircuits",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedEventsPage",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSectionsLinks",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionNextEventPageContentModulesVideosThumbnailImage",
    "GetWawCompetitionGetWawCompetitionNextEventPageEvent",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventCircuits",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventPage",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventPageEvent",
    "GetWawCompetitionGetWawCompetitionNextEventPageEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionNextEventPageMinisiteSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionPage",
    "GetWawCompetitionGetWawCompetitionPageCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBannersPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesBannersPageMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionPageContentModulesLocationsLocation",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEventCircuits",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageEventPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisitePageMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesMinisiteSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEventCircuits",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesEventPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedEventsPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsCircuits",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageCampaign",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageContentModules",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageEvent",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedEventsPageMinisite",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionPageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinks",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinksFile",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSectionsLinksPage",
    "GetWawCompetitionGetWawCompetitionPageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionPageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionPageContentModulesVideosThumbnailImage",
    "GetWawCompetitionGetWawCompetitionPageEvent",
    "GetWawCompetitionGetWawCompetitionPageEventCircuits",
    "GetWawCompetitionGetWawCompetitionPageEventPage",
    "GetWawCompetitionGetWawCompetitionPageEventPageCampaign",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModules",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesBanners",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesFeatureLinks",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesLifestyleLinks",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesLocations",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesMinisite",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesMinisitePage",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedArticles",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedCompetitors",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedDiscipline",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedEvents",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedMedia",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedVideo",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesRelatedVideos",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesSections",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesSlides",
    "GetWawCompetitionGetWawCompetitionPageEventPageContentModulesVideos",
    "GetWawCompetitionGetWawCompetitionPageEventPageEvent",
    "GetWawCompetitionGetWawCompetitionPageEventPageEventCircuits",
    "GetWawCompetitionGetWawCompetitionPageEventPageEventPage",
    "GetWawCompetitionGetWawCompetitionPageEventPageMinisite",
    "GetWawCompetitionGetWawCompetitionPageEventPageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionPageEventPageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionPageEventPageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionPageEventPageMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionPageMinisite",
    "GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsors",
    "GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawCompetitionGetWawCompetitionPageMinisiteFeatureImage",
    "GetWawCompetitionGetWawCompetitionPageMinisiteLogo",
    "GetWawCompetitionGetWawCompetitionPageMinisiteSponsors",
    "GetWawCompetitionGetWawCompetitionPageMinisiteSponsorsDarkBgLogo",
    "GetWawCompetitionGetWawCompetitionPageMinisiteSponsorsLightBgLogo",
    "GetWawEvent",
    "GetWawEventCountryList",
    "GetWawEventCountryListGetWawEventCountryList",
    "GetWawEventCountryListGetWawEventCountryListCountries",
    "GetWawEventGetWawEvent",
    "GetWawEventGetWawEventCircuits",
    "GetWawEventGetWawEventPage",
    "GetWawEventGetWawEventPageCampaign",
    "GetWawEventGetWawEventPageContentModules",
    "GetWawEventGetWawEventPageContentModulesBanners",
    "GetWawEventGetWawEventPageContentModulesBannersPage",
    "GetWawEventGetWawEventPageContentModulesBannersPageCampaign",
    "GetWawEventGetWawEventPageContentModulesBannersPageContentModules",
    "GetWawEventGetWawEventPageContentModulesBannersPageEvent",
    "GetWawEventGetWawEventPageContentModulesBannersPageMinisite",
    "GetWawEventGetWawEventPageContentModulesFeatureLinks",
    "GetWawEventGetWawEventPageContentModulesLifestyleLinks",
    "GetWawEventGetWawEventPageContentModulesLocations",
    "GetWawEventGetWawEventPageContentModulesLocationsLocation",
    "GetWawEventGetWawEventPageContentModulesMinisite",
    "GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsors",
    "GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawEventGetWawEventPageContentModulesMinisiteDefaultSponsorsLightBgLogo",
    "GetWawEventGetWawEventPageContentModulesMinisiteFeatureImage",
    "GetWawEventGetWawEventPageContentModulesMinisiteLogo",
    "GetWawEventGetWawEventPageContentModulesMinisitePage",
    "GetWawEventGetWawEventPageContentModulesMinisitePageCampaign",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModules",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesBanners",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesFeatureLinks",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesLifestyleLinks",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesLocations",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesMinisite",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesMinisitePage",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedArticles",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedCompetitors",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedDiscipline",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedEvents",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedMedia",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedVideo",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesRelatedVideos",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesSections",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesSlides",
    "GetWawEventGetWawEventPageContentModulesMinisitePageContentModulesVideos",
    "GetWawEventGetWawEventPageContentModulesMinisitePageEvent",
    "GetWawEventGetWawEventPageContentModulesMinisitePageEventCircuits",
    "GetWawEventGetWawEventPageContentModulesMinisitePageEventPage",
    "GetWawEventGetWawEventPageContentModulesMinisitePageMinisite",
    "GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteDefaultSponsors",
    "GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteFeatureImage",
    "GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteLogo",
    "GetWawEventGetWawEventPageContentModulesMinisitePageMinisiteSponsors",
    "GetWawEventGetWawEventPageContentModulesMinisiteSponsors",
    "GetWawEventGetWawEventPageContentModulesMinisiteSponsorsDarkBgLogo",
    "GetWawEventGetWawEventPageContentModulesMinisiteSponsorsLightBgLogo",
    "GetWawEventGetWawEventPageContentModulesRelatedArticles",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModules",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesLocations",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesRelatedVideo",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesContentModulesRelatedVideos",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesEventCircuits",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesEventPage",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesContentModules",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedArticles",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitions",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedCompetitors",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedDiscipline",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedEvents",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedLinks",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedArticlesRelatedMinisitePages",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsLastEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsNextEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitionsPage",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedCompetitorsPrimaryMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStats",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsDiscipline",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsPreviousMedalists",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsRecords",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsResults",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsSeasonBest",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedDisciplineStatsTimetable",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEventsCircuits",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedEventsPage",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesCampaign",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesContentModules",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedArticlesRelatedMinisitePagesMinisite",
    "GetWawEventGetWawEventPageContentModulesRelatedCompetitors",
    "GetWawEventGetWawEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedDiscipline",
    "GetWawEventGetWawEventPageContentModulesRelatedEvents",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsCircuits",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsPage",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsPageCampaign",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsPageContentModules",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsPageEvent",
    "GetWawEventGetWawEventPageContentModulesRelatedEventsPageMinisite",
    "GetWawEventGetWawEventPageContentModulesRelatedMedia",
    "GetWawEventGetWawEventPageContentModulesRelatedVideo",
    "GetWawEventGetWawEventPageContentModulesRelatedVideos",
    "GetWawEventGetWawEventPageContentModulesSections",
    "GetWawEventGetWawEventPageContentModulesSectionsLinks",
    "GetWawEventGetWawEventPageContentModulesSectionsLinksFile",
    "GetWawEventGetWawEventPageContentModulesSectionsLinksPage",
    "GetWawEventGetWawEventPageContentModulesSlides",
    "GetWawEventGetWawEventPageContentModulesVideos",
    "GetWawEventGetWawEventPageContentModulesVideosThumbnailImage",
    "GetWawEventGetWawEventPageEvent",
    "GetWawEventGetWawEventPageEventCircuits",
    "GetWawEventGetWawEventPageEventPage",
    "GetWawEventGetWawEventPageEventPageCampaign",
    "GetWawEventGetWawEventPageEventPageContentModules",
    "GetWawEventGetWawEventPageEventPageContentModulesBanners",
    "GetWawEventGetWawEventPageEventPageContentModulesFeatureLinks",
    "GetWawEventGetWawEventPageEventPageContentModulesLifestyleLinks",
    "GetWawEventGetWawEventPageEventPageContentModulesLocations",
    "GetWawEventGetWawEventPageEventPageContentModulesMinisite",
    "GetWawEventGetWawEventPageEventPageContentModulesMinisitePage",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedArticles",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedCompetitors",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedDiscipline",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedEvents",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedMedia",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedVideo",
    "GetWawEventGetWawEventPageEventPageContentModulesRelatedVideos",
    "GetWawEventGetWawEventPageEventPageContentModulesSections",
    "GetWawEventGetWawEventPageEventPageContentModulesSlides",
    "GetWawEventGetWawEventPageEventPageContentModulesVideos",
    "GetWawEventGetWawEventPageEventPageEvent",
    "GetWawEventGetWawEventPageEventPageEventCircuits",
    "GetWawEventGetWawEventPageEventPageEventPage",
    "GetWawEventGetWawEventPageEventPageMinisite",
    "GetWawEventGetWawEventPageEventPageMinisiteDefaultSponsors",
    "GetWawEventGetWawEventPageEventPageMinisiteFeatureImage",
    "GetWawEventGetWawEventPageEventPageMinisiteLogo",
    "GetWawEventGetWawEventPageEventPageMinisiteSponsors",
    "GetWawEventGetWawEventPageMinisite",
    "GetWawEventGetWawEventPageMinisiteDefaultSponsors",
    "GetWawEventGetWawEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawEventGetWawEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawEventGetWawEventPageMinisiteFeatureImage",
    "GetWawEventGetWawEventPageMinisiteLogo",
    "GetWawEventGetWawEventPageMinisiteSponsors",
    "GetWawEventGetWawEventPageMinisiteSponsorsDarkBgLogo",
    "GetWawEventGetWawEventPageMinisiteSponsorsLightBgLogo",
    "GetWawMedalDetails",
    "GetWawMedalDetailsGetWawMedalDetails",
    "GetWawMedalDetailsGetWawMedalDetailsCompetitor",
    "GetWawMedalDetailsGetWawMedalDetailsDiscipline",
    "GetWawMenu",
    "GetWawMenuGetWawMenu",
    "GetWawMenuGetWawMenuEvent",
    "GetWawMenuGetWawMenuEventCircuits",
    "GetWawMenuGetWawMenuEventPage",
    "GetWawMenuGetWawMenuEventPageCampaign",
    "GetWawMenuGetWawMenuEventPageContentModules",
    "GetWawMenuGetWawMenuEventPageContentModulesBanners",
    "GetWawMenuGetWawMenuEventPageContentModulesBannersPage",
    "GetWawMenuGetWawMenuEventPageContentModulesFeatureLinks",
    "GetWawMenuGetWawMenuEventPageContentModulesLifestyleLinks",
    "GetWawMenuGetWawMenuEventPageContentModulesLocations",
    "GetWawMenuGetWawMenuEventPageContentModulesLocationsLocation",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisite",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisiteDefaultSponsors",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisiteFeatureImage",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisiteLogo",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisitePage",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisitePageCampaign",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisitePageContentModules",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisitePageEvent",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisitePageMinisite",
    "GetWawMenuGetWawMenuEventPageContentModulesMinisiteSponsors",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticles",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesContentModules",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesEvent",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedCompetitors",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedDiscipline",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedEvents",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedEventsCircuits",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedEventsPage",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedMedia",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedVideo",
    "GetWawMenuGetWawMenuEventPageContentModulesRelatedVideos",
    "GetWawMenuGetWawMenuEventPageContentModulesSections",
    "GetWawMenuGetWawMenuEventPageContentModulesSectionsLinks",
    "GetWawMenuGetWawMenuEventPageContentModulesSlides",
    "GetWawMenuGetWawMenuEventPageContentModulesVideos",
    "GetWawMenuGetWawMenuEventPageContentModulesVideosThumbnailImage",
    "GetWawMenuGetWawMenuEventPageEvent",
    "GetWawMenuGetWawMenuEventPageEventCircuits",
    "GetWawMenuGetWawMenuEventPageEventPage",
    "GetWawMenuGetWawMenuEventPageEventPageCampaign",
    "GetWawMenuGetWawMenuEventPageEventPageContentModules",
    "GetWawMenuGetWawMenuEventPageEventPageEvent",
    "GetWawMenuGetWawMenuEventPageEventPageMinisite",
    "GetWawMenuGetWawMenuEventPageMinisite",
    "GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsors",
    "GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawMenuGetWawMenuEventPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawMenuGetWawMenuEventPageMinisiteFeatureImage",
    "GetWawMenuGetWawMenuEventPageMinisiteLogo",
    "GetWawMenuGetWawMenuEventPageMinisiteSponsors",
    "GetWawMenuGetWawMenuEventPageMinisiteSponsorsDarkBgLogo",
    "GetWawMenuGetWawMenuEventPageMinisiteSponsorsLightBgLogo",
    "GetWawMenuGetWawMenuItems",
    "GetWawMenuGetWawMenuItemsItems",
    "GetWawMenuGetWawMenuItemsItemsItems",
    "GetWawMenuGetWawMenuItemsItemsItemsItems",
    "GetWawMenuGetWawMenuItemsItemsItemsItemsItems",
    "GetWawMenuGetWawMenuItemsItemsItemsItemsPage",
    "GetWawMenuGetWawMenuItemsItemsItemsPage",
    "GetWawMenuGetWawMenuItemsItemsItemsPageCampaign",
    "GetWawMenuGetWawMenuItemsItemsItemsPageContentModules",
    "GetWawMenuGetWawMenuItemsItemsItemsPageEvent",
    "GetWawMenuGetWawMenuItemsItemsItemsPageMinisite",
    "GetWawMenuGetWawMenuItemsItemsPage",
    "GetWawMenuGetWawMenuItemsItemsPageCampaign",
    "GetWawMenuGetWawMenuItemsItemsPageContentModules",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesBanners",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesFeatureLinks",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesLifestyleLinks",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesLocations",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesMinisite",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesMinisitePage",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedArticles",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedCompetitors",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedDiscipline",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedEvents",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedMedia",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedVideo",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesRelatedVideos",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesSections",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesSlides",
    "GetWawMenuGetWawMenuItemsItemsPageContentModulesVideos",
    "GetWawMenuGetWawMenuItemsItemsPageEvent",
    "GetWawMenuGetWawMenuItemsItemsPageEventCircuits",
    "GetWawMenuGetWawMenuItemsItemsPageEventPage",
    "GetWawMenuGetWawMenuItemsItemsPageMinisite",
    "GetWawMenuGetWawMenuItemsItemsPageMinisiteDefaultSponsors",
    "GetWawMenuGetWawMenuItemsItemsPageMinisiteFeatureImage",
    "GetWawMenuGetWawMenuItemsItemsPageMinisiteLogo",
    "GetWawMenuGetWawMenuItemsItemsPageMinisiteSponsors",
    "GetWawMenuGetWawMenuItemsPage",
    "GetWawMenuGetWawMenuItemsPageCampaign",
    "GetWawMenuGetWawMenuItemsPageContentModules",
    "GetWawMenuGetWawMenuItemsPageContentModulesBanners",
    "GetWawMenuGetWawMenuItemsPageContentModulesBannersPage",
    "GetWawMenuGetWawMenuItemsPageContentModulesFeatureLinks",
    "GetWawMenuGetWawMenuItemsPageContentModulesLifestyleLinks",
    "GetWawMenuGetWawMenuItemsPageContentModulesLocations",
    "GetWawMenuGetWawMenuItemsPageContentModulesLocationsLocation",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisite",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisiteDefaultSponsors",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisiteFeatureImage",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisiteLogo",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisitePage",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageCampaign",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageContentModules",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageEvent",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisitePageMinisite",
    "GetWawMenuGetWawMenuItemsPageContentModulesMinisiteSponsors",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticles",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesContentModules",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesEvent",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedArticles",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedCompetitions",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedCompetitors",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedDiscipline",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedEvents",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedLinks",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedMedia",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedArticlesRelatedMinisitePages",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedCompetitors",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedCompetitorsPrimaryMedia",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedDiscipline",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedEvents",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedEventsCircuits",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedEventsPage",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedMedia",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedVideo",
    "GetWawMenuGetWawMenuItemsPageContentModulesRelatedVideos",
    "GetWawMenuGetWawMenuItemsPageContentModulesSections",
    "GetWawMenuGetWawMenuItemsPageContentModulesSectionsLinks",
    "GetWawMenuGetWawMenuItemsPageContentModulesSlides",
    "GetWawMenuGetWawMenuItemsPageContentModulesVideos",
    "GetWawMenuGetWawMenuItemsPageContentModulesVideosThumbnailImage",
    "GetWawMenuGetWawMenuItemsPageEvent",
    "GetWawMenuGetWawMenuItemsPageEventCircuits",
    "GetWawMenuGetWawMenuItemsPageEventPage",
    "GetWawMenuGetWawMenuItemsPageEventPageCampaign",
    "GetWawMenuGetWawMenuItemsPageEventPageContentModules",
    "GetWawMenuGetWawMenuItemsPageEventPageEvent",
    "GetWawMenuGetWawMenuItemsPageEventPageMinisite",
    "GetWawMenuGetWawMenuItemsPageMinisite",
    "GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsors",
    "GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsorsDarkBgLogo",
    "GetWawMenuGetWawMenuItemsPageMinisiteDefaultSponsorsLightBgLogo",
    "GetWawMenuGetWawMenuItemsPageMinisiteFeatureImage",
    "GetWawMenuGetWawMenuItemsPageMinisiteLogo",
    "GetWawMenuGetWawMenuItemsPageMinisiteSponsors",
    "GetWawMenuGetWawMenuItemsPageMinisiteSponsorsDarkBgLogo",
    "GetWawMenuGetWawMenuItemsPageMinisiteSponsorsLightBgLogo",
    "GetWawPlacingTableDetails",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetails",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetailsCompetitor",
    "GetWawPlacingTableDetailsGetWawPlacingTableDetailsDiscipline",
    "GetWawPlacingTables",
    "GetWawPlacingTablesGetWawPlacingTables",
    "GetWhereToWatch",
    "GetWhereToWatchGetWhereToWatch",
    "GetWhereToWatchGetWhereToWatchEventLevelGeneralChannels",
    "GetWhereToWatchGetWhereToWatchEventLevelGeneralChannelsDays",
    "GetWorldLeadingCompetitors",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitors",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitorTeamMembers",
    "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia",
    "GetWorldRanking",
    "GetWorldRankingGetWorldRanking",
    "GetWorldRankings",
    "GetWorldRankingsChanges",
    "GetWorldRankingsChangesGetWorldRankingsChanges",
    "GetWorldRankingsChangesGetWorldRankingsChangesChanges",
    "GetWorldRankingsGetWorldRankings",
    "GetWorldRankingsGetWorldRankingsParameters",
    "GetWorldRankingsGetWorldRankingsRankings",
    "HeadToHead",
    "HeadToHeadHeadToHead",
    "HeadToHeadHeadToHeadDisciplines",
    "HeadToHeadHeadToHeadOpponents",
    "HeadToHeadHeadToHeadParameters",
    "HeadToHeadHeadToHeadResults",
    "HeadToHeadHeadToHeadResultsResults",
    "LiveCombinedSummaryDetailInput",
    "LivePhaseSummaryInput",
    "LivePhaseSummaryQuery",
    "LiveResultInput",
    "LiveResultTeamMemberInput",
    "MedalDetailInput",
    "MedalInput",
    "MedalMutationInput",
    "MetaDataTypes",
    "MyAthletes",
    "MyAthletesMyAthletes",
    "MyAthletesMyAthletesPrimaryMedia",
    "OrderByEnum",
    "OrderByLiveBlogPostEnum",
    "OrderByNewArticleEnum",
    "OrderDirectionEnum",
    "PhaseInput",
    "PhaseQueryInput",
    "PlacingTableDetailInput",
    "PlacingTableInput",
    "PlacingTableOrderBy",
    "PreviousMedalQuery",
    "PreviousMedalists",
    "PreviousMedalistsPreviousMedalists",
    "RecordsByEvent",
    "RecordsByEventRecordsByEvent",
    "RecordsByEventRecordsByEventCompetitor",
    "RelatedCompetitionEnum",
    "ResultsByAthlete",
    "ResultsByAthleteResultsByAthlete",
    "ResultsByAthleteResultsByAthleteParameters",
    "ResultsByAthleteResultsByAthleteResults",
    "ResultsByAthleteResultsByAthleteResultsAthlete",
    "ResultsByAthleteResultsByAthleteResultsTeam",
    "ResultsByAthleteResultsByAthleteResultsTeamTeamMembers",
    "SearchAthletes",
    "SearchAthletesSearchAthletes",
    "SearchAthletesSearchAthletesCompetitionEntries",
    "SearchAthletesSearchAthletesCompetitionEntriesDiscipline",
    "SearchAthletesSearchAthletesDisciplines",
    "SearchAthletesSearchAthletesPrimaryMedia",
    "SearchCompetitors",
    "SearchCompetitorsSearchCompetitors",
    "SignCookies",
    "SignCookiesSignCookies",
    "TeamProfile",
    "TeamProfileTeamProfile",
    "TeamProfileTeamProfilePersonalBestInfo",
    "TeamProfileTeamProfilePersonalBests",
    "TeamProfileTeamProfilePersonalBestsDiscipline",
    "TeamProfileTeamProfilePersonalHonour",
    "TeamProfileTeamProfilePersonalHonourDiscipline",
    "TeamProfileTeamProfilePersonalHonourInfo",
    "TeamQuery",
    "TeamScoringInput",
    "TeamStandingOrderBy",
    "TeamStandings",
    "TeamStandingsInput",
    "TeamStandingsTeamStandings",
    "TeamStandingsTeamStandingsRelatedAthlete",
    "TeamStandingsTeamStandingsRelatedAthleteDetail",
    "UnitInput",
    "Upload",
    "VerifyCaptchaToken",
    "VerifyCaptchaTokenVerifyCaptchaToken",
    "VerifyHCaptchaToken",
    "VerifyHCaptchaTokenVerifyHCaptchaToken",
    "WorldAthletics",
    "eventPhaseOrderByEnum",
    "medalsOrderByEnum",
]
